%* lsaf_checkout                                                                                 *;
%*                                                                                               *;
%* Check out a SAS Life Science Analytics Framework repository file.                             *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %LSAF_CHECKOUT(LSAF_PATH=lsaf-path);                                                          *;
%*                                                                                               *;
%* @macvar _lsafRC_  the return code.                                                            *;
%* @macvar _lsafMsg_ the return message.                                                         *;
%*                                                                                               *;
%* @param lsaf_path - required - the path of the file within the SAS Life Science Analytics      *;
%*            Framework repository to check out.                                                 *;
%*                                                                                               *;
%* @macrotype LSAF                                                                               *;
%* @since 1.5                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2016-10-04 initial coding                                                            *;
%*                                                                                               *;

%macro lsaf_checkout(
  lsaf_path=
  ) /des='Enables check out of a SAS Life Science Analytics Framework repository file.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %lsaf_getProductName();

  %global _lsafMsg_
          _lsafRC_
  ;

  %let _lsafRC_=%str(-999);
  %let _lsafMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/RepositoryService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *;
    %***********************************;
    srv.callStaticVoidMethod("checkOut", "%bquote(&lsaf_path)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): &_LSAF_PRODUCT_NAME_ Macro:";
      logMsg=" Unable to check out the file: &lsaf_path.." ;
    end;
    else
    do;
      logMsgPrefix="NOTE: &_LSAF_PRODUCT_NAME_ Macro: * ";
      logMsg=" Check out successful for &lsaf_path..";
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _lsafMsg_= " message ;
    put logMsgPrefix " _lsafRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_lsafRC_", returnCode);
    call symputx("_lsafMsg_", message);

  run;

%mend lsaf_checkout;
