%* lsaf_createanalysis                                                                     *;
%*                                                                                         *;
%* Creates an analysis in the SAS Life Science Analytics Framework repository.             *;
%*                                                                                         *;
%* The parent project must already exist.                                                  *;
%*                                                                                         *;
%* Syntax:                                                                                 *;
%* %LSAF_CREATEANALYSIS(LSAF_PATH=lsaf-path);                                              *;
%*                                                                                         *;
%* @macvar _lsafRC_  the return code.                                                      *;
%* @macvar _lsafMsg_ the return message.                                                   *;
%*                                                                                         *;
%* @param lsaf_path - required - the path of the analysis being created.                   *;
%*                                                                                         *;
%* @macrotype LSAF                                                                         *;
%* @since 1.2                                                                              *;
%* @exposure external                                                                      *;
%*                                                                                         *;
%* @history 2013-08-30  updates for standardization and coding conventions                 *;
%* @history 2016-08-26  rebrand as LSAF                                                    *;
%*                                                                                         *;

%macro lsaf_createanalysis(
  lsaf_path=
  ) /des='Create an analysis.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %lsaf_getProductName();

  %global _lsafMsg_
          _lsafRC_
  ;

  %let _lsafRC_=%str(-999);
  %let _lsafMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/AnalysisService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *;
    %***********************************;
    srv.callStaticVoidMethod("create", "%bquote(&lsaf_path)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode eq 0) then
    do;
      logMsgPrefix="NOTE: &_LSAF_PRODUCT_NAME_ Macro: * ";
      logMsg=" * The analysis was created: &lsaf_path" ;
    end;
    else
    do;
      logMsgPrefix="ERR%str(OR): &_LSAF_PRODUCT_NAME_ Macro:";
      logMsg=" Cannot create analysis: &lsaf_path" ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _lsafMsg_= " message ;
    put logMsgPrefix " _lsafRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_lsafRC_", returnCode);
    call symputx("_lsafMsg_", message);

  run;

%mend lsaf_createanalysis ;
