%* lsaf_createuser                                                                                 *;
%*                                                                                                 *;
%* Creates a user account within the system.                                                       *;
%*                                                                                                 *;
%* Syntax:                                                                                         *;
%* %LSAF_CREATEUSER(LSAF_USERID=lsaf-userid, LSAF_DISPLAYNAME=lsaf-displayname,                    *;
%* LSAF_EMAIL=lsaf-email, LSAF_ACCOUNTTYPE=lsaf-accounttype, LSAF_PASSWORD=lsaf-password,          *;
%* <, LSAF_FIRSTNAME=lsaf-firstname, LSAF_LASTNAME=lsaf-lastname,                                  *;
%* LSAF_DEPARTMENT=lsaf-department,LSAF_PHONE=lsaf-phone>);                                        *;
%*                                                                                                 *;
%* @macvar _lsafRC_  the return code.                                                              *;
%* @macvar _lsafMsg_ the return message.                                                           *;
%*                                                                                                 *;
%* @param lsaf_userid - required - the user ID of the account to create.                           *;
%* @param lsaf_displayname - required - the display name of the account to create.                 *;
%* @param lsaf_email - required - the email address of the account to create.                      *;
%* @param lsaf_accounttype - required - the account type of the account to create.                 *;
%*            Values:  INTERACTIVE | NON_INTERACTIVE                                               *;
%*            Default: None                                                                        *;
%* @param lsaf_password - required - the password for the account to create.                       *;
%* @param lsaf_firstname - optional - the first name of the user associated with this account.     *;
%* @param lsaf_lastname - optional - the last name of the user associated with this account.       *;
%* @param lsaf_department - optional - the business unit of the user associated with this account. *;
%* @param lsaf_phone - optional - the phone number of the user associated with this account.       *;
%*                                                                                                 *;
%* @macrotype LSAF                                                                                 *;
%* @since 1.3                                                                                      *;
%* @exposure external                                                                              *;
%*                                                                                                 *;
%* @history 2013-10-30 initial coding                                                              *;
%* @history 2016-08-26  rebrand as LSAF                                                            *;
%*                                                                                                 *;

%macro lsaf_createuser(
  lsaf_userid=,
  lsaf_displayname=,
  lsaf_email=,
  lsaf_accounttype=,
  lsaf_password=,
  lsaf_firstname=,
  lsaf_lastname=,
  lsaf_department=,
  lsaf_phone=
  ) /des='Create a user account in the system.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %lsaf_getProductName();

  %global _lsafMsg_
          _lsafRC_
  ;

  %let _lsafRC_=%str(-999);
  %let _lsafMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/UserService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *;
    %***********************************;
    srv.callStaticVoidMethod("create", "%bquote(&lsaf_userid)", "%bquote(&lsaf_displayname)", "%bquote(&lsaf_email)",
                             "%bquote(&lsaf_accounttype)", "%bquote(&lsaf_password)", "%bquote(&lsaf_firstname)",
                             "%bquote(&lsaf_lastname)", "%bquote(&lsaf_department)", "%bquote(&lsaf_phone)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    logMsgPrefix="NOTE: &_LSAF_PRODUCT_NAME_ Macro: * ";
    logMsg=" The user &lsaf_userid was created." ;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): &_LSAF_PRODUCT_NAME_ Macro:";
      logMsg=" Cannot create user &lsaf_userid." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _lsafMsg_= " message ;
    put logMsgPrefix " _lsafRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_lsafRC_", returnCode);
    call symputx("_lsafMsg_", message);

  run;

%mend lsaf_createuser;
