%* lsaf_encryptpassword                                                                          *;
%*                                                                                               *;
%* Encrypts the password for a user in the system. The returned encrypted password can be used   *;
%* as a valid password for login to SAS Life Science Analytics Framework. The encrypted password *;
%* is invalid for the user interface login to SAS Life Science Analytics Framework. The value of *;
%* the encrypted password is printed to the log.                                                 *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %LSAF_ENCRYPTPASSWORD(LSAF_PASSWORD=lsaf-password);                                           *;
%*                                                                                               *;
%* @macvar _lsafRC_  the return code.                                                            *;
%* @macvar _lsafMsg_ the return message.                                                         *;
%*                                                                                               *;
%* @param lsaf_password - required - the password to encrypt.                                    *;
%*                                                                                               *;
%* @macrotype LSAF                                                                               *;
%* @since 1.5                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2016-09-26 initial coding                                                            *;
%*                                                                                               *;

%macro lsaf_encryptpassword(
  lsaf_password=
  ) /des='Encrypt a password for a user.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %lsaf_getProductName();

  %global _lsafMsg_
          _lsafRC_
  ;

  %let _lsafRC_=%str(-999);
  %let _lsafMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode        length=8;
    attrib message           length=$200;
    attrib logMsgPrefix      length=$70;
    attrib logMsg            length=$300;

    attrib encryptedPassword length=$64;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/UserService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *;
    %***********************************;
    srv.callStaticStringMethod("encryptPassword", "%bquote(&lsaf_password)", results, encryptedPassword);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode eq 0) then
    do;
      logMsgPrefix="NOTE: &_LSAF_PRODUCT_NAME_ Macro: * ";
      logMsg=" The password was successfully encrypted." ;
    end;
    else
    do;
      logMsgPrefix="ERR%str(OR): &_LSAF_PRODUCT_NAME_ Macro:";
      logMsg=" Unable to encrypt the password." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _lsafMsg_= " message ;
    put logMsgPrefix " _lsafRC_= " returnCode ;
    if (returnCode eq 0) then put logMsgPrefix " The encrypted password is " encryptedPassword ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_lsafRC_", returnCode);
    call symputx("_lsafMsg_", message);
  run;

%mend lsaf_encryptpassword;
