%* lsaf_markforaddandcheckin                                                                      *;
%*                                                                                                *;
%* Marks for add and checks in a workspace file to the SAS Life Science Analytics Framework       *;
%* repository                                                                                     *;
%*                                                                                                *;
%* Syntax:                                                                                        *;
%* %LSAF_MARKFORADDANDCHECKIN(LSAF_PATH=lsaf-path                                                 *;
%*                            <,LSAF_VERSIONFILE=lsaf-version-file,                               *;
%*                            LSAF_COMMENT=lsaf-comment,                                          *;
%*                            LSAF_VERSIONTYPE=lsaf-version-type,                                 *;
%*                            LSAF_CUSTOMVERSION=lsaf-custom-version>);                           *;
%*                                                                                                *;
%* @macvar _lsafRC_  the return code.                                                             *;
%* @macvar _lsafMsg_ the return message.                                                          *;
%*                                                                                                *;
%* @param lsaf_path - required -  the path of the file.                                           *;
%* @param lsaf_versionfile - optional - A boolean value representing whether or not to version    *;
%*                  the file. Values are 1 for yes and 0 for no. The default is 1 (Yes).          *;
%* @param lsaf_comment - optional - A comment when versioning a file                              *;
%* @param lsaf_versiontype - optional - What level to version the file, valid values are MAJOR,   *;
%*                  MINOR, and CUSTOM. MAJOR for whole number updates (ie 3.0 to 4.0), MINOR for  *;
%*                  incremental updates (ie 3.0 to 3.1), and CUSTOM for user specifed versioning  *;
%*                  (ie 6.1).  The default is MAJOR.                                              *;
%* @param lsaf_customversion - conditional - A numeric value for a custom version (ie 6.1) when   *;
%*                  lsaf_versiontype=CUSTOM, otherwise this parameter is ignored.                 *;
%*                                                                                                *;
%* @macrotype LSAF                                                                                *;
%* @since 1.5                                                                                     *;
%* @exposure external                                                                             *;
%*                                                                                                *;
%* @history 2016-11-28  initial code                                                              *;
%*                                                                                                *;

%macro lsaf_markforaddandcheckin(
  lsaf_path=,
  lsaf_versionfile=1,
  lsaf_comment=,
  lsaf_versiontype=MAJOR,
  lsaf_customversion=
  ) /des='Marks for add and checks in a workspace file to the SAS Life Science Analytics Framework repository';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %lsaf_getProductName();

  %global _lsafMsg_
          _lsafRC_
  ;

  %let _lsafRC_ =%str(-999);
  %let _lsafMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/RepositoryService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *;
    %***********************************;
    srv.callStaticVoidMethod("markForAddAndCheckInFileFromWorkspace", "%bquote(&lsaf_path)", "%bquote(&lsaf_versionfile)",
       "%bquote(&lsaf_comment)", "%bquote(&lsaf_versiontype)", "%bquote(&lsaf_customversion)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): &_LSAF_PRODUCT_NAME_ Macro:";
      logMsg=" Cannot mark for add and check in workspace file: &lsaf_path." ;
    end;
    else
    do;
      logMsgPrefix="NOTE: &_LSAF_PRODUCT_NAME_ Macro: * ";
      logMsg=" Workspace file (&lsaf_path) has been marked for add and checked in to the repository." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _lsafMsg_= " message;
    put logMsgPrefix " _lsafRC_= " returnCode;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_lsafRC_", returnCode);
    call symputx("_lsafMsg_", message);

  run;

%mend lsaf_markforaddandcheckin;
