%* lsaf_renameproject                                                                            *;
%*                                                                                               *;
%* Renames a project.                                                                            *;
%*                                                                                               *;
%* Another project with the new name must not already exist in the organization.                 *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %LSAF_RENAMEPROJECT(LSAF_SOURCE=lsaf-source-path, LSAF_NEWNAME=lsaf-new-name);                *;
%*                                                                                               *;
%* @macvar _lsafRC_  the return code.                                                            *;
%* @macvar _lsafMsg_ the return message.                                                         *;
%*                                                                                               *;
%* @param lsaf_source   - required - the path, including the name, of the project to be renamed. *;
%* @param lsaf_newname  - required - the new name of the project.                                *;
%*                                                                                               *;
%* @macrotype LSAF                                                                               *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2014-03-04  initial coding                                                           *;
%* @history 2016-08-26  rebrand as LSAF                                                          *;
%*                                                                                               *;

%macro lsaf_renameproject(
  lsaf_source=,
  lsaf_newname=
  ) /des='Rename a project.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %lsaf_getProductName();

  %global _lsafMsg_
          _lsafRC_
  ;

  %let _lsafRC_=%str(-999);
  %let _lsafMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %*  Start the datastep to call the java code  *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/ProjectService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *;
    %***********************************;
    srv.callStaticVoidMethod("rename", "%bquote(&lsaf_source)", "%bquote(&lsaf_newname)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode eq 0) then
    do;
      logMsgPrefix="NOTE: &_LSAF_PRODUCT_NAME_ Macro: * ";
      logMsg=" The project rename operation was successful.";
    end;
    else
    do;
      logMsgPrefix="ERR%str(OR): &_LSAF_PRODUCT_NAME_ Macro:";
      logMsg=" Cannot successfully rename the project.  The project was not renamed." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _lsafMsg_= " message ;
    put logMsgPrefix " _lsafRC_= " returnCode ;
    put logMsgPrefix " lsaf_source = &lsaf_source" ;
    put logMsgPrefix " lsaf_newname = &lsaf_newname" ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_lsafRC_", returnCode);
    call symputx("_lsafMsg_", message);

  run;

%mend lsaf_renameproject;
