%* lsaf_resetpassword                                                                            *;
%*                                                                                               *;
%* Reset the password for a user in the system.  This action requires the logged on user to have *;
%* the administrative privilege PRIVILEGE_MANAGE_USER_ACCOUNTS.  Once the password has been      *;
%* successfully reset, the user can immediately log on with the new password, but they will be   *;
%* forced to change their password immediately so the password remains unique to the user.       *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %LSAF_RESETPASSWORD(LSAF_USERID=lsaf-userid, LSAF_NEWPASSWORD=lsaf-password);                 *;
%*                                                                                               *;
%* @macvar _lsafRC_  the return code.                                                            *;
%* @macvar _lsafMsg_ the return message.                                                         *;
%*                                                                                               *;
%* @param lsaf_userid - required - the user ID of the account to reset.                          *;
%* @param lsaf_newpassword - required - the new temporary password.                              *;
%*                                                                                               *;
%* @macrotype LSAF                                                                               *;
%* @since 1.3                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2013-11-04 initial coding                                                            *;
%* @history 2016-08-26  rebrand as LSAF                                                          *;
%*                                                                                               *;

%macro lsaf_resetpassword(
  lsaf_userid=,
  lsaf_newpassword=
  ) /des='Reset the password for an account in the system.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %lsaf_getProductName();

  %global _lsafMsg_
          _lsafRC_
  ;

  %let _lsafRC_=%str(-999);
  %let _lsafMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/UserService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *;
    %***********************************;
    srv.callStaticVoidMethod("resetPassword", "%bquote(&lsaf_userid)", "%bquote(&lsaf_newpassword)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode eq 0) then
    do;
      logMsgPrefix="NOTE: &_LSAF_PRODUCT_NAME_ Macro: * ";
      logMsg=" The password for the account &lsaf_userid was successfully reset." ;
    end;
      else
    do;
      logMsgPrefix="ERR%str(OR): &_LSAF_PRODUCT_NAME_ Macro:";
      logMsg=" Unable to reset the password for the account &lsaf_userid.." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _lsafMsg_= " message ;
    put logMsgPrefix " _lsafRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_lsafRC_", returnCode);
    call symputx("_lsafMsg_", message);

  run;

%mend lsaf_resetpassword;
