%* lsaf_transition                                                                               *;
%*                                                                                               *;
%* Internal macro prints rebranding message to the log for the change from SASDRUGDEV to LSAF.   *;
%* Used only in the SASDRUGDEV macros.                                                           *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %LSAF_TRANSITION(                                                                             *;
%*     SDD_MACRO_NAME=name-of-SASDRUGDEV-macro,                                                  *;
%*     SDD_ANSWER_VAR=Additional-output-var-in-log,                                              *;
%*     LSAF_ANSWER_VAR=LSAF-equivalent-SDD-answer-var,                                           *;
%*                                                                                               *;
%* Example Code:                                                                                 *;
%*   %lsaf_transition(                                                                           *;
%*    sdd_macro_name=sasdrugdev_getobjecttype                                                    *;
%*    sdd_answer_var=_sddObjectType_,                                                            *;
%*    lsaf_answer_val=&_lsafObjectType_                                                          *;
%*    );                                                                                         *;
%*                                                                                               *;
%* In the above example, the sasdrugdev_getobjecttype macro name is passed into lsaf_transition, *;
%* in addition sdd_answer_var =_sddObjectType_ and lsaf_answer_var=&_lsafObjectType_ are also    *;
%* given values because this macro has an additional output to the log other than _sddRC_ and    *;
%* _sddMsg_.                                                                                     *;
%*                                                                                               *;
%*                                                                                               *;
%* @param SDD_MACRO_NAME - The name of the sasdrugdev macro calling lsaf_transition.             *;
%* @param SDD_ANSWER_VAR - Variable output to the log other than _sddRC_ and _sddMsg_. Some      *;
%* sasdrugdev macros output an additional variable to the log, this field captures that variable.*;
%* @param LSAF_ANSWER_VAR - This is the equivalent LSAF name of the additional SASDRUGDEV var.   *;
%*                                                                                               *;
%* @macrotype LSAF                                                                               *;
%* @since 1.5                                                                                    *;
%* @exposure internal                                                                            *;
%*                                                                                               *;
%* @history 2016-08-30  Initial coding                                                           *;
%*                                                                                               *;
%macro lsaf_transition(
   sdd_macro_name=,
   sdd_answer_var=%str(),
   lsaf_answer_val=%str()
   );

   %local _msgPrint;

   %let notesOption=%sysfunc(getoption(notes));
   %let _sddRC_=&_lsafRC_;
   %let _sddMsg_=&_lsafMsg_;
   %let lsaf_macro_name=%sysfunc(tranwrd(&sdd_macro_name,sasdrugdev,lsaf));

   %*********************************************;
   %* Rebrand message for SASDRUGDEV API macros *;
   %*********************************************;
   %put;
   %put NOTE: ***********************************************************************************;
   %put NOTE: The %upcase(&sdd_macro_name) macro will be deprecated in the next release of       ;
   %put NOTE: SAS Life Science Analytics Framework and replaced with %upcase(&lsaf_macro_name).  ;
   %put NOTE: ***********************************************************************************;
   %put;

   options nonotes;
   %if (&sdd_answer_var NE %str()) %then
   %do;
      data _null_;
         call symput("&sdd_answer_var", "&lsaf_answer_val");
      run;
   %end;
   options &notesOption;

   %if %eval(&_sddRC_) lt 0 %then %let _msgPrint=ERROR: SAS Drug Development Macro:;
     %else %let _msgPrint=NOTE: SAS Drug Development Macro:;

   %put &_msgPrint * _sddRC_  = &_sddRC_;
   %put &_msgPrint * _sddMsg_ = &_sddMsg_;
   %if (&sdd_answer_var NE %str()) %then %put &_msgPrint * &sdd_answer_var = &&&sdd_answer_var;
   %put;

%mend lsaf_transition;
