%* lsaf_updateprojectlead                                                                         *;
%*                                                                                                *;
%* Updates the current lead of a project in the SAS Life Science Analytics Framework repository.  *;
%*                                                                                                *;
%* Syntax for files:                                                                              *;
%* %LSAF_UPDATEPROJECTLEAD(LSAF_PATH=lsaf-path, LSAF_USERID=lsaf-userid);                         *;
%*                                                                                                *;
%* @macvar _lsafRC_  the return code.                                                             *;
%* @macvar _lsafMsg_ the return message.                                                          *;
%*                                                                                                *;
%* @param lsaf_path - required - the path of the project in the SAS Life Science Analytics        *;
%*      Framework repository.                                                                     *;
%* @param lsaf_userid - required - the user ID for the account that will be the new lead.         *;
%*                                                                                                *;
%* @macrotype LSAF                                                                                *;
%* @since 1.4                                                                                     *;
%* @exposure external                                                                             *;
%*                                                                                                *;
%* @history 2014-05-01  initial coding.                                                           *;
%* @history 2016-08-26  rebrand as LSAF                                                           *;
%*                                                                                                *;

%macro lsaf_updateprojectlead(
  lsaf_path=,
  lsaf_userid=
  ) /des='Change the lead of an project.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %lsaf_getProductName();

  %global _lsafMsg_
          _lsafRC_
  ;

  %let _lsafRC_=%str(-999);
  %let _lsafMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/ProjectService") ;
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *;
    %***********************************;
    srv.callStaticVoidMethod("updateLead", "%bquote(&lsaf_path)", "%bquote(&lsaf_userid)", results) ;

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    if (returnCode eq 0) then
    do;
      logMsgPrefix="NOTE: &_LSAF_PRODUCT_NAME_ Macro: * ";
      logMsg=" The lead was changed to &lsaf_userid for project &lsaf_path.." ;
    end;
    else
    do;
      logMsgPrefix="ERR%str(OR): &_LSAF_PRODUCT_NAME_ Macro:";
      logMsg=" Cannot change the lead for project &lsaf_path.." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _lsafMsg_= " message ;
    put logMsgPrefix " _lsafRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_lsafRC_", returnCode);
    call symputx("_lsafMsg_", message);

  run;

%mend lsaf_updateprojectlead;
