%* lsaf_updateuserinfo                                                                           *;
%*                                                                                               *;
%* Update general user account information.                                                      *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %LSAF_UPDATEUSERINFO(LSAF_USERID=lsaf-userid, < LSAF_DISPLAYNAME=lsaf-displayname,            *;
%* LSAF_EMAIL=lsaf-email, LSAF_ACCOUNTTYPE=lsaf-accounttype, LSAF_FIRSTNAME=lsaf-firstname,      *;
%* LSAF_LASTNAME=lsaf-lastname, LSAF_DEPARTMENT=lsaf-department, LSAF_PHONE=lsaf-phone >);       *;
%*                                                                                               *;
%* You must have either the Manage User Account General Information or the Manage Users global   *;
%* privilege in order to update user information.                                                *;
%*                                                                                               *;
%* If an optional parameter is not passed in, no change to the existing user attribute value     *;
%* will be made.  If the parameter is pased in, the specified value will be set on the user      *;
%* attribute. Parameter values must conform to LSAF validation rules.                            *;
%*                                                                                               *;
%* @macvar _lsafRC_  the return code.                                                            *;
%* @macvar _lsafMsg_ the return message.                                                         *;
%*                                                                                               *;
%* @param lsaf_userid - required - the user ID of the account being updated.                     *;
%* @param lsaf_displayname - optional - the user display name to be set.                         *;
%* @param lsaf_email - optional - the user email address.                                        *;
%* @param lsaf_accounttype - optional - the user account type.                                   *;
%*            Values:  INTERACTIVE | NON_INTERACTIVE                                             *;
%* @param lsaf_firstname - optional - the user first name.                                       *;
%* @param lsaf_lastname - optional - the last name of the user.                                  *;
%* @param lsaf_department - optional - the business unit of the user.                            *;
%* @param lsaf_phone - optional - the phone number of the user.                                  *;
%*                                                                                               *;
%* @macrotype LSAF                                                                               *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2014-03-27 initial coding                                                            *;
%* @history 2016-08-26  rebrand as LSAF                                                          *;
%*                                                                                               *;

%macro lsaf_updateuserinfo(
  lsaf_userid=,
  lsaf_displayname=_lsaf_updateuser_donotupdate_,
  lsaf_email=_lsaf_updateuser_donotupdate_,
  lsaf_accounttype=_lsaf_updateuser_donotupdate_,
  lsaf_firstname=_lsaf_updateuser_donotupdate_,
  lsaf_lastname=_lsaf_updateuser_donotupdate_,
  lsaf_department=_lsaf_updateuser_donotupdate_,
  lsaf_phone=_lsaf_updateuser_donotupdate_
  ) /des='Update a user account in the system.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %lsaf_getProductName();

  %global _lsafMsg_
          _lsafRC_
  ;

  %let _lsafRC_=%str(-999);
  %let _lsafMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %**********************************************;
  %* Start the datastep to call the java code   *;
  %**********************************************;
  data _null_;
    attrib returnCode      length=8;
    attrib message         length=$200;
    attrib logMsgPrefix    length=$70;
    attrib logMsg          length=$300;

    %***********************************;
    %* Declare the java objects        *;
    %***********************************;
    declare javaobj srv("com/sas/hls/macro/service/UserService");
    declare javaobj results("com/sas/hls/macro/results/Result");

    %***********************************;
    %* Attempt the operation           *;
    %***********************************;
    srv.callStaticVoidMethod("update", "%bquote(&lsaf_userid)", "%bquote(&lsaf_displayname)", "%bquote(&lsaf_email)",
                             "%bquote(&lsaf_accounttype)", "%bquote(&lsaf_firstname)", "%bquote(&lsaf_lastname)",
                             "%bquote(&lsaf_department)", "%bquote(&lsaf_phone)", results);

    %***********************************;
    %* Retrieve the results            *;
    %***********************************;
    results.callIntMethod("getReturnCode", returnCode);
    results.callStringMethod("getReturnMessage", message);

    %***********************************;
    %* Process the results             *;
    %***********************************;
    logMsgPrefix="NOTE: &_LSAF_PRODUCT_NAME_ Macro: * ";
    logMsg=" The user account &lsaf_userid was updated." ;
    if (returnCode ne 0) then
    do;
      logMsgPrefix="ERR%str(OR): &_LSAF_PRODUCT_NAME_ Macro:";
      logMsg=" Cannot update user account &lsaf_userid." ;
    end;

    %***********************************;
    %* Print messages in log           *;
    %***********************************;
    put;
    put logMsgPrefix " " %sysfunc(lowcase("&SYSMACRONAME"));
    put logMsgPrefix " " logMsg;
    put logMsgPrefix " _lsafMsg_= " message ;
    put logMsgPrefix " _lsafRC_= " returnCode ;
    put;

    %***********************************;
    %* Set the macro variables         *;
    %***********************************;
    call symputx("_lsafRC_", returnCode);
    call symputx("_lsafMsg_", message);

  run;

%mend lsaf_updateuserinfo;
