%* sasdrugdev_addgroupmember                                                                     *;
%*                                                                                               *;
%* Adds a user or group as a member of a group in the specified organization, project, or        *;
%* analysis.                                                                                     *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_ADDGROUPMEMBER(SDD_PATH=sdd-path, SDD_GROUP=sdd-group-name,                       *;
%*    SDD_MEMBER=sdd-member-identifier <, SDD_TYPE=sdd-member-type,                              *;
%*    SDD_GROUP_CONTEXT=sdd-group-context>);                                                     *;
%*                                                                                               *;
%* Example Code                                                                                  *;
%* Context paths used in examples:                                                               *;
%* -  Organization: /SAS                                                                         *;
%* -  Project:      /SAS/Project1                                                                *;
%* -  Analysis:     /SAS/Project1/Analysis1                                                      *;
%*                                                                                               *;
%* 1. Add User as a Group member at the Project level:                                           *;
%*    %sasdrugdev_addgroupmember(sdd_path=%str(/SAS/Project1), sdd_group=%str(PrjGrp1),          *;
%*    sdd_member=%str(User1), sdd_type=%str(USER));                                              *;
%*                                                                                               *;
%* 2. Add Group as a Group member at the Project level:                                          *;
%*    %sasdrugdev_addgroupmember(sdd_path=%str(/SAS/Project1), sdd_group=%str(PrjGrp1),          *;
%*    sdd_member=%str(OrgGrp1), sdd_type=%str(GROUP), sdd_group_context=%str(/SAS));             *;
%*                                                                                               *;
%* 3. Add User as a Group member at the Analysis level:                                          *;
%*    %sasdrugdev_addgroupmember(sdd_path=%str(/SAS/Project1/Analysis1),                         *;
%*    sdd_group=%str(AnaGrp1), sdd_member=%str(User1), sdd_type=%str(USER));                     *;
%*                                                                                               *;
%* 4. Add Project Group as a Group member at the Analysis level:                                 *;
%*    %sasdrugdev_addgroupmember(sdd_path=%str(/SAS/Project1/Analysis1),                         *;
%*    sdd_group=%str(AnaGrp1), sdd_member=%str(PrjGrp1), sdd_type=%str(GROUP),                   *;
%*    sdd_group_context=%str(/SAS/Project1));                                                    *;
%*                                                                                               *;
%* 5. Add Organization Group as a Group member at the Analysis level:                            *;
%*    %sasdrugdev_addgroupmember(sdd_path=%str(/SAS/Project1/Analysis1),                         *;
%*    sdd_group=%str(AnaGrp1), sdd_member=%str(OrgGrp1), sdd_type=%str(GROUP),                   *;
%*    sdd_group_context=%str(/SAS));                                                             *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the context object (organization, project, or        *;
%*            analysis) where the group is defined.                                              *;
%* @param sdd_group - required - the name of the group to add the member.                        *;
%* @param sdd_member - required - the user ID of the user or the name of the group being added.  *;
%* @param sdd_type - conditional - the type of member being added.                               *;
%*            Values:  USER | GROUP (case-insensitive)                                           *;
%*            Default: USER                                                                      *;
%* @param sdd_group_context - conditional - specifies the context in which the group is defined  *;
%*            as a path (e.g., /SAS). This parameter is required if SDD_TYPE=GROUP. Otherwise,   *;
%*            it will be ignored.                                                                *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_addgroupmember, effective with SAS LSAF Macro 1.5                *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-26  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_addgroupmember(
  sdd_path=,
  sdd_group=,
  sdd_type=USER,
  sdd_member=,
  sdd_group_context=
  ) /des='Add a member to the group in the specified context.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_addgroupmember(lsaf_path=&sdd_path,
    lsaf_group=&sdd_group,
    lsaf_type=&sdd_type,
    lsaf_member=&sdd_member,
    lsaf_group_context=&sdd_group_context
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_addgroupmember;
