%* sasdrugdev_addmember                                                                          *;
%*                                                                                               *;
%* Adds a user or a group as a member of the specified organization, project, or analysis.       *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_ADDMEMBER(SDD_PATH=sdd-path, SDD_MEMBER=sdd-member-identifier,                    *;
%*    <SDD_TYPE=sdd-member-type, SDD_GROUP_CONTEXT=sdd-group-context>);                          *;
%*                                                                                               *;
%* Example Code                                                                                  *;
%* Context paths used in examples:                                                               *;
%* -  Organization: /SAS                                                                         *;
%* -  Project:      /SAS/Project1                                                                *;
%* -  Analysis:     /SAS/Project1/Analysis1                                                      *;
%*                                                                                               *;
%* 1. Add User as a Member at the Project level:                                                 *;
%*    %sasdrugdev_addmember(SDD_PATH=%str(/SAS/Project1), SDD_MEMBER=%str(User1));               *;
%*                                                                                               *;
%* 2. Add Group as a Member at the Project level:                                                *;
%*    %sasdrugdev_addmember(sdd_path=%str(/SAS/Project1), sdd_member=%str(OrgGrp1),              *;
%*    sdd_type=%str(GROUP), sdd_group_context=%str(/SAS));                                       *;
%*                                                                                               *;
%* 3. Add User as a Member at the Analysis level:                                                *;
%*    %sasdrugdev_addmember(SDD_PATH=%str(/SAS/Project1/Analysis1), SDD_MEMBER=%str(User1));     *;
%*                                                                                               *;
%* 4. Add Group defined at Organization level as a Member at the Analysis level:                 *;
%*    %sasdrugdev_addmember(sdd_path=%str(/SAS/Project1/Analysis1), sdd_member=%str(OrgGrp1),    *;
%*    sdd_type=%str(GROUP), sdd_group_context=%str(/SAS));                                       *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path required - the path of the context object (organization, project, or          *;
%*            analysis) where the member is being added.                                         *;
%* @param sdd_member required - the user ID of the user or the name of the group being added.    *;
%* @param sdd_type conditional - the type of member being added.                                 *;
%*            Values:  USER | GROUP (case-insensitive)                                           *;
%*            Default: USER                                                                      *;
%* @param sdd_group_context - conditional - specifies the context in which the group is defined  *;
%*            as a path (e.g., /SAS). This parameter is required if SDD_TYPE=GROUP. Otherwise,   *;
%*            it will be ignored.                                                                *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_addmember, effective with SAS LSAF Macro 1.5                     *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-26  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_addmember(
  sdd_path=,
  sdd_member=,
  sdd_type=USER,
  sdd_group_context=
  ) /des='Add the member to a context.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_addmember(
    lsaf_path=&sdd_path,
    lsaf_member=&sdd_member,
    lsaf_type=&sdd_type,
    lsaf_group_context=&sdd_group_context
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
   );

%mend sasdrugdev_addmember ;
