%* sasdrugdev_addroleprivilege                                                                   *;
%*                                                                                               *;
%* Adds a privilege to a role in the specified organization, project, or analysis.               *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_ADDROLEPRIVILEGE(SDD_PATH=sdd-path, SDD_ROLE=sdd-role-name,                       *;
%* SDD_PRIVILEGE=sdd-privilege-id);                                                              *;
%*                                                                                               *;
%* Example Code:                                                                                 *;
%* Use %sasdrugdev_getcontextprivileges to fetch the list of available privileges at a specified *;
%* context. The macro returns a SAS data set containing the list of privileges (the default      *;
%* name of the data set is work.sddgetcontextprivileges).  Use one of the privilegeId values to  *;
%* add that privilege to a Role.                                                                 *;
%*                                                                                               *;
%* 1. Retrieve the available privileges at a Project:                                            *;
%*    %sasdrugdev_getcontextprivileges(sdd_path=%str(/SAS/Project1));                            *;
%*                                                                                               *;
%* 2. Add a privilege to a Role:                                                                 *;
%*    %sasdrugdev_addroleprivilege(sdd_path=%str(/SAS/Project1), sdd_role=%str(PrjRole1),        *;
%*    sdd_privilege=%str(PRIVILEGE_SIGN_FILE));                                                  *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the context object (organization, project, or        *;
%*            analysis) where the role is defined.                                               *;
%* @param sdd_role - required - the name of the role to add the privilege.                       *;
%* @param sdd_privilege - required - the identifier of the privilege being added.                *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_addroleprivilege, effective with SAS LSAF Macro 1.5              *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-26  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_addroleprivilege(
  sdd_path=,
  sdd_role=,
  sdd_privilege=
  ) /des='Add a privilege to the role in the specified context.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_addroleprivilege(lsaf_path=&sdd_path,
    lsaf_role=&sdd_role,
    lsaf_privilege=&sdd_privilege
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
      sdd_macro_name=%lowcase(&_sddMacro_),
      sdd_answer_var=,
      lsaf_answer_val=
   );

%mend sasdrugdev_addroleprivilege;
