%* sasdrugdev_adduserprivilege                                                                   *;
%*                                                                                               *;
%* Assign a global privilege to a user in the system.                                            *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_ADDUSERPRIVILEGE(SDD_USERID=sdd-user-id, SDD_PRIVILEGE=sdd-privilege-id);         *;
%*                                                                                               *;
%* Example Code:                                                                                 *;
%* Use %sasdrugdev_getglobalprivileges to fetch the list of available global privileges. The     *;
%* macro returns a SAS data set containing the list of privileges (the default name of the       *;
%* data set is work.sddgetglobalprivileges).  Use one of the privilegeId values to assign that   *;
%* global privilege to a User.                                                                   *;
%*                                                                                               *;
%* 1. Retrieve the available global privileges:                                                  *;
%*    %sasdrugdev_getglobalprivileges();                                                         *;
%*                                                                                               *;
%* 2. Assign a privilege to a User:                                                              *;
%*    %sasdrugdev_adduserprivilege(sdd_userid=%str(User1),                                       *;
%*    sdd_privilege=%str(PRIVILEGE_AUDIT_REPORTING));                                            *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_userid - required - the user to assign the global privilege.                       *;
%* @param sdd_privilege - required - the identifier of the global privilege to assign.           *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.3                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_adduserprivilege, effective with SAS LSAF Macro 1.5              *;
%*                                                                                               *;
%* @history 2013-11-01  initial coding                                                           *;
%* @history 2016-08-26  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_adduserprivilege(
  sdd_userid=,
  sdd_privilege=
  ) /des='Assign a global privilege to a user.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_adduserprivilege(lsaf_userid=&sdd_userid,
    lsaf_privilege=&sdd_privilege
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
      sdd_macro_name=%lowcase(&_sddMacro_),
      sdd_answer_var=,
      lsaf_answer_val=
   );

%mend sasdrugdev_adduserprivilege;
