%* sasdrugdev_assignedroleexists                                                                 *;
%*                                                                                               *;
%* Determine if a role exists (as defined or inherited) in an organization, project, or analysis.*;
%*                                                                                               *;
%* The SAS macro variable _sddAssignedRoleExists_ is set to a value of 1 if the role exists, 0   *;
%* if it does not. In the event of an incorrect call to the macro which results in an error, the *;
%* return value of _sddAssignedRoleExists_ will be set to -1.                                    *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_ASSIGNEDROLEEXISTS (SDD_PATH=sdd-path, SDD_ROLE=sdd-role-name,                    *;
%* SDD_ROLE_CONTEXT=sdd-role-context);                                                           *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%* @macvar _sddAssignedRoleExists_  indicates the existence of the assigned role in the context. *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the context object (organization, project, or        *;
%*            analysis).                                                                         *;
%* @param sdd_role - required - the name of the role to check for existence.                     *;
%* @param sdd_role_context - required - specifies the context in which the role is defined as a  *;
%*            path (e.g., /SAS).                                                                 *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_assignedroleexists, effective with SAS LSAF Macro 1.5            *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-26  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_assignedroleexists(
  sdd_path=,
  sdd_role=,
  sdd_role_context=
  ) /des='Is the role assigned to a context.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddAssignedRoleExists_
          _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_assignedroleexists(lsaf_path=&sdd_path,
    lsaf_role=&sdd_role,
    lsaf_role_context=&sdd_role_context
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=_sddAssignedRoleExists_,
    lsaf_answer_val=&_lsafAssignedRoleExists_
  );

%mend sasdrugdev_assignedroleexists ;
