%* sasdrugdev_copy                                                                               *;
%*                                                                                               *;
%* Copies a file or folder to the specified target location.                                     *;
%*                                                                                               *;
%* The copy of a versioned file will not be versioned. The children of a copied folder will      *;
%* also be copied to the new location in their original directory structure.                     *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_COPY(SDD_SOURCE=sdd-source-path, SDD_TARGET=sdd-target-path);                     *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_source - required - the path of the object to be copied.                           *;
%* @param sdd_target - required - the path (including the new name) where the object is to be    *;
%*            copied. The target folder must already exist.                                      *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.1                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_copy, effective with SAS LSAF Macro 1.5                          *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-26  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_copy(
  sdd_source=,
  sdd_target=
  ) /des='Copy a file or folder.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_copy(lsaf_source=&sdd_source,
    lsaf_target=&sdd_target
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_copy ;
