%* sasdrugdev_createfile                                                                         *;
%*                                                                                               *;
%* Uploads a file from the local machine to the SAS Drug Development repository.                 *;
%*                                                                                               *;
%* All parent folders that do not already exist will be created as well.                         *;
%*                                                                                               *;
%* NOTE: This macro is only supported from a PC SAS session. Using this macro within an active   *;
%* SAS Drug Development application session will result in a failure.                            *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_CREATEFILE(LOCAL_PATH=local-path, SDD_PATH=sdd-path                               *;
%* <, SDD_VERSIONING=sdd-versioning, SDD_VERSION=sdd-version, SDD_COMMENT=sdd_comment>);         *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param local_path - required - the absolute path and name of the file on the local computer.  *;
%* @param sdd_path - required - the path of the file to be created. Files can only be created in *;
%*            SAS Drug Development in areas that support folder and file creation. They cannot   *;
%*            be created at the organization, project, or analysis levels.                       *;
%* @param sdd_versioning - optional - indicates whether the file being created should be         *;
%*            versioned. The default value is 0, which will create a non-versioned file.  A      *;
%*            value of 1 will create a versioned file.                                           *;
%*            Values:  0 | 1                                                                     *;
%*            Default: 0                                                                         *;
%* @param sdd_version - conditional - indicates the version number to assign to the file being   *;
%*            created. The value must be in the valid version label format including a decimal   *;
%*            point.  This option is ignored when creating non-versioned file.                   *;
%* @param sdd_comment - conditional - the comment for the versioned file being created. This     *;
%*            option is ignored when creating a non-versioned file.                              *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.1                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_createfile, effective with SAS LSAF Macro 1.5                    *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-26  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_createfile(
  local_path=,
  sdd_path=,
  sdd_versioning=,
  sdd_version=,
  sdd_comment=
  ) /des='Upload a file from the local computer as a new file into SAS Drug Development.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_createfile(local_path=&local_path,
    lsaf_path=&sdd_path,
    lsaf_versioning=&sdd_versioning,
    lsaf_version=&sdd_version,
    lsaf_comment=&sdd_comment
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_createfile ;
