%* sasdrugdev_createfolder                                                                       *;
%*                                                                                               *;
%* Creates a folder in the SAS Drug Development repository.                                      *;
%*                                                                                               *;
%* All parent folders that do not already exist will be created as well. Folders can only be     *;
%* created under \Files or an existing folder, not directly under the organization, project,     *;
%* or analysis.                                                                                  *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_CREATEFOLDER(SDD_PATH=sdd-path);                                                  *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the folder to be created.                            *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.1                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_createfolder, effective with SAS LSAF Macro 1.5                  *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-30  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_createfolder(
  sdd_path=
  ) /des='Create a folder.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_createfolder(lsaf_path=&sdd_path);

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_createfolder ;
