%* sasdrugdev_createrole                                                                         *;
%*                                                                                               *;
%* Creates a role in the specified organization, project, or analysis.                           *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_CREATEROLE(SDD_PATH=sdd-path, SDD_ROLE=sdd-role-name                              *;
%* <, SDD_DESCRIPTION=sdd-description>);                                                         *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the context object (organization, project, or        *;
%*            analysis) where the role will be defined.                                          *;
%* @param sdd_role - required - the name of the role being created.                              *;
%* @param sdd_description - optional - the description for the role being created.               *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_createrole, effective with SAS LSAF Macro 1.5                    *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-30  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_createrole(
  sdd_path=,
  sdd_role=,
  sdd_description=
  ) /des='Create a role in the specified context.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_createrole(
    lsaf_path=&sdd_path,
    lsaf_role=&sdd_role,
    lsaf_description=&sdd_description
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_createrole ;
