%* sasdrugdev_createuser                                                                         *;
%*                                                                                               *;
%* Creates a user account within the system.                                                     *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_CREATEUSER(SDD_USERID=sdd-userid, SDD_DISPLAYNAME=sdd-displayname,                *;
%* SDD_EMAIL=sdd-email, SDD_ACCOUNTTYPE=sdd-accounttype, SDD_PASSWORD=sdd-password,              *;
%* <, SDD_FIRSTNAME=sdd-firstname, SDD_LASTNAME=sdd-lastname, SDD_DEPARTMENT=sdd-department,     *;
%* SDD_PHONE=sdd-phone>);                                                                        *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_userid - required - the user ID of the account to create.                          *;
%* @param sdd_displayname - required - the display name of the account to create.                *;
%* @param sdd_email - required - the email address of the account to create.                     *;
%* @param sdd_accounttype - required - the account type of the account to create.                *;
%*            Values:  INTERACTIVE | NON_INTERACTIVE                                             *;
%*            Default: None                                                                      *;
%* @param sdd_password - required - the password for the account to create.                      *;
%* @param sdd_firstname - optional - the first name of the user associated with this account.    *;
%* @param sdd_lastname - optional - the last name of the user associated with this account.      *;
%* @param sdd_department - optional - the business unit of the user associated with this account.*;
%* @param sdd_phone - optional - the phone number of the user associated with this account.      *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.3                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_createuser, effective with SAS LSAF Macro 1.5                    *;
%*                                                                                               *;
%* @history 2013-10-30 initial coding                                                            *;
%* @history 2016-08-30 initial coding                                                            *;
%*                                                                                               *;

%macro sasdrugdev_createuser(
  sdd_userid=,
  sdd_displayname=,
  sdd_email=,
  sdd_accounttype=,
  sdd_password=,
  sdd_firstname=,
  sdd_lastname=,
  sdd_department=,
  sdd_phone=
  ) /des='Create a user account in the system.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_createuser(
    lsaf_userid=&sdd_userid,
    lsaf_displayname=&sdd_displayname,
    lsaf_email=&sdd_email,
    lsaf_accounttype=&sdd_accounttype,
    lsaf_password=&sdd_password,
    lsaf_firstname=&sdd_firstname,
    lsaf_lastname=&sdd_lastname,
    lsaf_department=&sdd_department,
    lsaf_phone=&sdd_phone
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_createuser;
