%* sasdrugdev_disableversioning                                                                  *;
%*                                                                                               *;
%* Disables versioning on a SAS Drug Development repository file.                                *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_DISABLEVERSIONING(SDD_PATH=sdd-path <, SDD_COMMENT=sdd-comment>);                 *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the file within the SAS Drug Development repository  *;
%*            to be set to unversioned.                                                          *;
%* @param sdd_comment - optional - a note associated with the action of disabling versioning.    *;
%*            The value is visible through the Audit Trail.                                      *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.5                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2014-04-07 initial coding                                                            *;
%* @history 2016-10-03 Make external and rebrand to LSAF                                         *;
%*                                                                                               *;

%macro sasdrugdev_disableversioning(
  sdd_path=,
  sdd_comment=
  ) /des='Disable versioning on a SAS Drug Development repository file.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_disableversioning(
    lsaf_path=&sdd_path,
    lsaf_comment=&sdd_comment
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_disableversioning;
