%* sasdrugdev_downloadaszip                                                                      *;
%*                                                                                               *;
%* Downloads SAS Drug Development files or a folder along with its content to your local machine *;
%* as a zip file.                                                                                *;
%*                                                                                               *;
%* If the local directory does not exist it will be created.  If the local file does not exist   *;
%* it will be created.  If the object being downloaded is a folder, the contents of the folder   *;
%* will be downloaded with its hierarchy maintained. If the object being downloaded is a project *;
%* or an analysis, only the containers (depots, folders) with files will be downloaded.          *;
%*                                                                                               *;
%* NOTE: This macro is only supported from a PC SAS session. Using this macro within an active   *;
%* SAS Drug Development application session will result in a failure.                            *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_DOWNLOADASZIP(SDD_PATH=sdd-path, LOCAL_PATH=local-zipfile-path                    *;
%* <,SDD_OVERWRITE=sdd-overwrite> );                                                             *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the object (file or container) to be downloaded.     *;
%* @param local_path - required - the full path and name of the file to create (or overwrite,    *;
%*            if applicable) on the local computer.                                              *;
%* @param sdd_overwrite - optional -  indicates whether or not to overwrite the existing zip     *;
%*            file on the local machine.  The valid values are 0 and 1 to maintain or overwrite  *;
%*            the file respectively.  The default is 0.                                          *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_downloadaszip, effective with SAS LSAF Macro 1.5                 *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-30  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_downloadaszip(
  sdd_path=,
  local_path=,
  sdd_overwrite=0
  ) /des='Downloads a SAS Drug Development repository object as a zip file.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_downloadaszip(
    lsaf_path=&sdd_path,
    local_path=&local_path,
    lsaf_overwrite=&sdd_overwrite
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_downloadaszip;
