%* sasdrugdev_downloadfile                                                                       *;
%*                                                                                               *;
%* Downloads a file to your local machine from the SAS Drug Development repository.              *;
%*                                                                                               *;
%* If the local directory does not exist it will be created.  If the local file does not exist   *;
%* it will be created.  If the local file does exist, it will be overwritten with new content.   *;
%*                                                                                               *;
%* NOTE: This macro is only supported from a PC SAS session. Using this macro within an active   *;
%* SAS Drug Development application session will result in a failure.                            *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_DOWNLOADFILE(SDD_PATH=sdd-path, SDD_VERSION=sdd- version>, LOCAL_PATH=local-path);*;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the file within the SAS Drug Development repository  *;
%*            to download.                                                                       *;
%* @param sdd_version - conditional - specifies the version of the file to download if the file  *;
%*            is versioned.  If the file is versioned and a specific version is specified the    *;
%*            value must be in the valid format including a decimal point such as 1.0 or 4.2.    *;
%*            If the file is versioned and no version is specified the latest version is         *;
%*            downloaded.  If the file is unversioned and a specific version is specified that   *;
%*            will result in a failure.                                                          *;
%* @param local_path - required - the full path and name of the file to create (or overwrite,    *;
%*            if it exists) on the local computer.                                               *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.3                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_downloadfile, effective with SAS LSAF Macro 1.5                  *;
%*                                                                                               *;
%* @history 2013-10-30 initial coding                                                            *;
%* @history 2016-08-30 rebrand for LSAF                                                          *;
%*                                                                                               *;

%macro sasdrugdev_downloadfile(
  sdd_path=,
  sdd_version=,
  local_path=
  ) /des='Download a file to your local computer from the SAS Drug Development repository.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_downloadfile(
    lsaf_path=&sdd_path,
    lsaf_version=&sdd_version,
    local_path=&local_path
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_downloadfile;
