%* sasdrugdev_enableversioning                                                                   *;
%*                                                                                               *;
%* Enables versioning on a SAS Drug Development repository file.                                 *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_ENABLEVERSIONING(SDD_PATH=sdd-path <, SDD_VERSION=sdd-version,                    *;
%*        SDD_COMMENT=sdd-comment>);                                                             *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the file within the SAS Drug Development repository  *;
%*            to version.                                                                        *;
%* @param sdd_version - optional - specifies the starting version number of the file. If not     *;
%*            specified, the value will default to 1.0.  The value must be in the valid format   *;
%*            including a decimal point such as 1.0 or 4.2.                                      *;
%* @param sdd_comment - optional - a note associated with the action of enabling versioning.     *;
%*            The value is visible through the Audit Trail.                                      *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.5                                                                                    *;
%* @exposure external                                                                            *;
%*                                                                                               *;
%* @history 2016-04-07 initial coding                                                            *;
%* @history 2016-10-03 Make external and rebrand to LSAF                                         *;
%*                                                                                               *;

%macro sasdrugdev_enableversioning(
  sdd_path=,
  sdd_version=,
  sdd_comment=
  ) /des='Enable versioning on a SAS Drug Development repository file.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_enableversioning(
    lsaf_path=&sdd_path,
    lsaf_version=&sdd_version,
    lsaf_comment=&sdd_comment
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_enableversioning;
