%* sasdrugdev_getallusers                                                                          *;
%*                                                                                                 *;
%* Returns a SAS data set that contains the metadata for all of the users defined within the       *;
%* system.                                                                                         *;
%*                                                                                                 *;
%* Syntax:                                                                                         *;
%* %SASDRUGDEV_GETALLUSERS(<,SAS_DSNAME=SAS-data-set>);                                            *;
%*                                                                                                 *;
%* @macvar _sddRC_  the return code.                                                               *;
%* @macvar _sddMsg_ the return message.                                                            *;
%*                                                                                                 *;
%* @param sas_dsname - optional - the name of the output SAS data set that contains the metadata   *;
%*            for the users specified as libref.dataset.  The default value is                     *;
%*            WORK.SDDGETALLUSERS.  The data set contains a row for each user, sorted by user      *;
%*            ID, and columns with the following names:                                            *;
%*            - userId: The unique login identifier for this account.                              *;
%*            - displayName: The display name for the account.                                     *;
%*            - firstName: The first name of the user.                                             *;
%*            - lastName: The last name of the user.                                               *;
%*            - email: The email address for this user.                                            *;
%*            - department: The business unit this user is a part of.                              *;
%*            - phone: The phone number for this user.                                             *;
%*            - isAccountActive: A numeric flag indicating whether the account is active (0=no,    *;
%*                  1=yes).                                                                        *;
%*            - isAccountLocked: A numeric flag indicating whether the account is locked (0=no,    *;
%*                  1=yes).                                                                        *;
%*            - accountActivationDate: The date this account becomes active, this value is         *;
%*                  represented in character format.                                               *;
%*            - accountDeactivationDate: The date this account becomes inactive, this value is     *;
%*                  represented in character format.                                               *;
%*            - accountLockedBy: The user ID who locked this account.                              *;
%*            - accountLockedDate: The date this account was locked, this value is represented     *;
%*                  in character format.                                                           *;
%*            - accountStatusBy: The user ID who changed the status of this account.               *;
%*            - accountStatusDate: The date the account status was last modified, this value is    *;
%*                  represented in character format.                                               *;
%*            - accountType: The type of account, valid values are INTERACTIVE and NON_INTERACTIVE *;
%*            - lastLogin: The date of the last time this account was logged onto, this value is   *;
%*                  represented in character format.                                               *;
%*            - loginAttempts: The current number of failed login attempts associated with this    *;
%*                  account.  If the number exceeds the configured threshold, this account will    *;
%*                  be locked.  This counter gets reset when a successful login occurs.            *;
%*            - loginCount: The total number of successful logins for this account.                *;
%*            - passwordCreated: The date the current password was created, this value is          *;
%*                  represented in character format.                                               *;
%*            - passwordExpiration: The date the current password expires, this value is           *;
%*                  represented in character format.                                               *;
%*            - isPasswordExpired: A numeric flag indicating whether the password has expired      *;
%*                  (0=no, 1=yes).                                                                 *;
%*            - dateAccountActivation: The date this account becomes active, this value is         *;
%*                  represented in SAS DateTime format.                                            *;
%*            - dateAccountDeactivation: The date this account becomes inactive, this value is     *;
%*                  represented in SAS DateTime format.                                            *;
%*            - dateAccountLocked: The date this account was locked, this value is represented     *;
%*                  in SAS DateTime format.                                                        *;
%*            - dateAccountStatus: The date the account status was last modified, this value is    *;
%*                  represented in SAS DateTime format.                                            *;
%*            - dateLastLogin: The date of the last time this account was logged onto, this        *;
%*                  value is represented in SAS DateTime format.                                   *;
%*            - datePasswordCreated: The date the current password was created, this value is      *;
%*                  represented in SAS DateTime format.                                            *;
%*            - datePasswordExpiration: The date the current password expires, this value is       *;
%*                  represented in SAS DateTime format.                                            *;
%*                                                                                                 *;
%* @macrotype SDD                                                                                  *;
%* @since 1.3                                                                                      *;
%* @exposure external                                                                              *;
%* @deprecated Replaced by lsaf_getallusers, effective with SAS LSAF Macro 1.5                     *;
%*                                                                                                 *;
%* @history 2013-10-30 initial coding                                                              *;
%* @history 2016-08-30 rebrand for LSAF                                                            *;
%*                                                                                                 *;
%macro sasdrugdev_getallusers(
  sas_dsname=work.sddGetAllUsers
  ) /des='Get a list of all users defined in the system.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_getallusers(sas_dsname=&sas_dsname);

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_getallusers;
