%* sasdrugdev_getassignedmembers                                                                 *;
%*                                                                                               *;
%* Returns a SAS data set that contains the metadata for all of the members assigned to the      *;
%* specified organization, project, or analysis.                                                 *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETASSIGNEDMEMBERS(SDD_PATH=sdd-path <, SAS_DSNAME=SAS-data-set>);                *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the context object (organization, project, or        *;
%*            analysis) containing the members.                                                  *;
%* @param sas_dsname - optional - the name of the output SAS data set that will contain the      *;
%*            metadata for the members specified as libref.dataset. The default value is         *;
%*            WORK.SDDGETASSIGNEDMEMBERS. The data set contains a row for each member and        *;
%*            columns with the following names.  The data set will be sorted by member type      *;
%*            and principalId.                                                                   *;
%*            - contextPath: The path of the context object in the repository.                   *;
%*            - type:  The member type.  Valid values are USER and GROUP.                        *;
%*            - principalId: The name of the member.  The returned values will be either a group *;
%*                  name or a user ID.                                                           *;
%*            - description: The description of the member. The returned values will be either a *;
%*                  group name or a user display name.                                           *;
%*            - grpSrcCtxt: The context path in which the group member was defined if the member *;
%*                  is a group.                                                                  *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_getassignedmembers, effective with SAS LSAF Macro 1.5            *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-30  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_getassignedmembers(
  sdd_path=,
  sas_dsname=work.sddGetAssignedMembers
  ) /des='Get a list of the assigned members in an SAS Drug Development context.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_getassignedmembers(
    lsaf_path=&sdd_path,
    sas_dsname=&sas_dsname
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_getassignedmembers;
