%* sasdrugdev_getconfiguration                                                                   *;
%*                                                                                               *;
%* Reports the current configuration settings.                                                   *;
%*                                                                                               *;
%* The values can be printed in the SAS log as well as being included in the data set.           *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETCONFIGURATION(<SAS_DSNAME=SAS-data-set, SAS_SUPPRESSLOGLIST=suppressloglist>); *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sas_dsname - optional - the name of the output SAS data set that contains the          *;
%*            configuration information as libref.dataset. The default value is                  *;
%*            WORK.SDDGETCONFIGURATION. The data set contains a row for each setting and columns *;
%*            with the following names. The data set will be sorted by name.                     *;
%*            - name: The name of the configuration item.                                        *;
%*            - value: The value of the configuration item.                                      *;
%*                                                                                               *;
%* @param sas_suppressLogList - optional - flag to suppress the print of the configuration       *;
%*            information to the log.  The default value is 0.  If the parameter is included     *;
%*            and the value is anything other than 0, the configuration values are not printed   *;
%*            to the log.                                                                        *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.3                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_getconfiguration, effective with SAS LSAF Macro 1.5              *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2014-04-04  changed exposure to external                                             *;
%* @history 2016-08-30  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_getconfiguration(
   sas_dsname=work.sddGetConfiguration,
   sas_suppressLogList=0
  ) /des='Get SAS Drug Development Macro configuration information.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_getconfiguration(
    sas_dsname=&sas_dsname,
    sas_suppressLogList=&sas_suppressLogList
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_getconfiguration ;
