%* sasdrugdev_getcontextprivileges                                                               *;
%*                                                                                               *;
%* Returns a SAS data set that contains the metadata for all of the privileges available in the  *;
%* specified organization, project, or analysis.                                                 *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETCONTEXTPRIVILEGES(SDD_PATH=sdd-path <, SAS_DSNAME=SAS-data-set>);              *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the context object (organization, project, or        *;
%*            analysis).                                                                         *;
%* @param sas_dsname - optional - the name of the output SAS data set that contains the metadata *;
%*            for the objects specified as libref.dataset. The default value is                  *;
%*            WORK.SDDGETCONTEXTPRIVILEGES. The data set contains a row for each privilege       *;
%*            defined at the context and columns with the following names. The data set will be  *;
%*            sorted by privilegeId.                                                             *;
%*            - contextPath: The path of the context object in the repository.                   *;
%*            - privilegeId: The identifier of the privilege.                                    *;
%*            - privilegeName: The name of the privilege.                                        *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_getcontextprivileges, effective with SAS LSAF Macro 1.5          *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-30  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_getcontextprivileges(
  sdd_path=,
  sas_dsname=work.sddGetContextPrivileges
  )  /des='Get a list of the privileges available for an SDD context.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_getcontextprivileges(
    lsaf_path=&sdd_path,
    sas_dsname=&sas_dsname
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_getcontextprivileges;
