%* sasdrugdev_getglobalprivileges                                                                *;
%*                                                                                               *;
%* Returns a SAS data set that contains the metadata for all of the global privileges available  *;
%* in the system.                                                                                *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETGLOBALPRIVILEGES(<SAS_DSNAME=SAS-data-set>);                                   *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sas_dsname - optional - the name of the output SAS data set that contains the metadata *;
%*            for all of the global privileges specified as libref.dataset. The default value is *;
%*            WORK.SDDGETGLOBALPRIVILEGES.  The data set contains a row for each global privilege*;
%*            and columns with the following names. The data set will be sorted by privilegeId.  *;
%*            - privilegeId: The identifier of the privilege.                                    *;
%*            - privilegeName: The name of the privilege.                                        *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.3                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_getglobalprivileges, effective with SAS LSAF Macro 1.5           *;
%*                                                                                               *;
%* @history 2013-11-01 initial coding                                                            *;
%* @history 2014-04-21 updated documentation                                                     *;
%* @history 2016-08-30 rebrand for LSAF                                                          *;
%*                                                                                               *;

%macro sasdrugdev_getglobalprivileges(
  sas_dsname=work.sddGetGlobalPrivileges
  )  /des='Get a list of all global privileges.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_getglobalprivileges(sas_dsname=&sas_dsname);

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_getglobalprivileges;
