%* sasdrugdev_getgroupmembers                                                                    *;
%*                                                                                               *;
%* Returns a SAS data set that contains the metadata for all of the members assigned to a group  *;
%* within the specified organization, project, or analysis.                                      *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETGROUPMEMBERS(SDD_PATH=sdd-path, SDD_GROUP=sdd-group                            *;
%* <, SAS_DSNAME=SAS-data-set>);                                                                 *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the context object (organization, project, or        *;
%*            analysis) where the group is defined.                                              *;
%* @param sdd_group - required - the name of the group                                           *;
%* @param sas_dsname - optional - the name of the output SAS data set that contains the metadata *;
%*            for the members specified as libref.data set. The default value is                 *;
%*            WORK.SDDGETGROUPMEMBERS. The data set contains a row for each member and columns   *;
%*            with the following names. The data set will be sorted by member type and           *;
%*            principalId.                                                                       *;
%*            - contextPath: The full path of the context object in the repository.              *;
%*            - type: The member type.  Valid values are USER and GROUP.                         *;
%*            - principalId: The name of the member.  Valid values are group name or user ID.    *;
%*            - description: The description of the member. Valid values are group name or user  *;
%*                  display name.                                                                *;
%*            - grpSrcCtxt: The context in which the of group member was defined.                *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_getgroupmembers, effective with SAS LSAF Macro 1.5               *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-30  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_getgroupmembers(
  sdd_path=,
  sdd_group=,
  sas_dsname=work.sddGetGroupMembers
  ) /des='Get a list of the members of a group in an SDD context.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_getgroupmembers(
    lsaf_path=&sdd_path,
    lsaf_group=&sdd_group,
    sas_dsname=&sas_dsname
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_getgroupmembers;
