%* sasdrugdev_getjobinfo                                                                           *;
%*                                                                                                 *;
%* Returns a SAS data set that contains the information for a job in the SAS Drug Development      *;
%* repository. This is the information displayed on the General tab of the job editor, as well as  *;
%* the information concerning the versioning of new outputs.                                       *;
%*                                                                                                 *;
%* Syntax:                                                                                         *;
%* %SASDRUGDEV_GETJOBINFO(SDD_PATH=sdd-path <, SDD_VERSION=sdd-version, SAS_DSNAME=SAS-data-set>); *;
%*                                                                                                 *;
%* @macvar _sddRC_  the return code.                                                               *;
%* @macvar _sddMsg_ the return message.                                                            *;
%*                                                                                                 *;
%* @param sdd_path - required - the path of the job in the SAS Drug Development repository.        *;
%* @param sdd_version - optional - a specific version number of the job. If not specified,         *;
%*            the information for the latest version will be returned.  Specifying a version for   *;
%*            a non-versioned job will cause an error.                                             *;
%* @param sas_dsname - optional - the name of the output SAS data set that contains the metadata   *;
%*            for the job specified as libref.dataset. The default value is                        *;
%*            WORK.SDDGETJOBINFO. The data set will contain variables representing each            *;
%*            element of metadata for the object.  The data set will be sorted by the NAME         *;
%*            variable.  The following metadata will be represented in the data set.               *;
%*            - path: The path of the job.                                                         *;
%*            - versionLabel: The label associated with the specified version of the job.          *;
%*            - name: The name of the property or attribute.                                       *;
%*            - value: The value of the property or attribute.                                     *;
%*                                                                                                 *;
%* @macrotype SDD                                                                                  *;
%* @since 1.4                                                                                      *;
%* @exposure external                                                                              *;
%* @deprecated Replaced by lsaf_getjobinfo, effective with SAS LSAF Macro 1.5                      *;
%*                                                                                                 *;
%* @history 2014-04-08  initial coding.                                                            *;
%* @history 2016-08-30  rebrand for LSAF                                                           *;
%*                                                                                                 *;

%macro sasdrugdev_getjobinfo(
  sdd_path=,
  sdd_version=,
  sas_dsname=work.sddGetJobInfo
  ) /des='Get the metadata for SAS Drug Development repository job.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_getjobinfo(
    lsaf_path=&sdd_path,
    lsaf_version=&sdd_version,
    sas_dsname=&sas_dsname
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_getjobinfo ;
