%* sasdrugdev_getjoboutputs                                                                      *;
%*                                                                                               *;
%* Returns a SAS data set containing metadata for the outputs for the specified job in the SAS   *;
%* Drug Development repository.                                                                  *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETJOBOUTPUTS(SDD_PATH=sdd-path <SDD_VERSION=sdd-version,                         *;
%*                  SAS_DSNAME=SAS-data-set>);                                                   *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the job.                                             *;
%* @param sdd_version - optional - the version of the job. If not specified, the latest version  *;
%*            will be used.                                                                      *;
%* @param sas_dsname - optional - the name of the output SAS data set that will contain the      *;
%*            metadata for the outputs specified as libref.dataset. The default value is         *;
%*            WORK.SDDGETJOBOUTPUTS. The data set contains a row for each job output and columns *;
%*            with the following names.  The data set will retain the order of the outputs.      *;
%*            - jobPath: The path of the job.                                                    *;
%*            - jobVersion: The job version.                                                     *;
%*            - outputPath: The path of the output location.                                     *;
%*            - outputIncludesSubFolders: A flag indicating whether or not the subfolders of an  *;
%*              output container are to be included during job execution.                        *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_getjoboutputs, effective with SAS LSAF Macro 1.5                 *;
%*                                                                                               *;
%* @history 2014-04-22  initial coding.                                                          *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_getjoboutputs(
   sdd_path=,
   sdd_version=,
   sas_dsname=work.sddGetJobOutputs
   ) /des='Get a list of the outputs for a job.';

   %****************************************;
   %* Initialize macro variables           *;
   %****************************************;
   %global _sddMsg_
           _sddRC_
   ;

   %let _sddRC_ =%str(-999);
   %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_getjoboutputs(
    lsaf_path=&sdd_path,
    lsaf_version=&sdd_version,
    sas_dsname=&sas_dsname
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_getjoboutputs;
