%* sasdrugdev_getjobparameters                                                                   *;
%*                                                                                               *;
%* Returns a SAS data set containing job parameter metadata for the specified job.               *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETJOBPARAMETERS(SDD_PATH=sdd-path <SDD_VERSION=sdd-version,                      *;
%*                  SAS_DSNAME=SAS-data-set>);                                                   *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the job.                                             *;
%* @param sdd_version - optional - the version of the job. If not specified, the latest version  *;
%*            will be used.                                                                      *;
%* @param sas_dsname - optional - the name of the output SAS data set that will contain the      *;
%*            metadata for the parameters specified as libref.dataset. The default value is      *;
%*            WORK.SDDGETJOBPARAMETERS. The data set contains a row for each job parameter       *;
%*            and columns with the following names.  The data set will retain the job parameter  *;
%*            order.                                                                             *;
%*            - jobPath: The path of the job.                                                    *;
%*            - jobVersion: The job version.                                                     *;
%*            - name: The name of the parameter.                                                 *;
%*            - label: The parameter label.                                                      *;
%*            - type: The parameter type.  Values are CHARACTER, CHARACTER_MASKED, NUMERIC,      *;
%*                  DATE, FILE, or FOLDER.                                                       *;
%*            - defaultValue: the default value for the parameter. Dates are returned in SAS     *;
%*                  datetime format.                                                             *;
%*            - fileVersion: the file version to be used if the parameter is of type FILE.       *;
%*                  A blank value means that either the file is not versioned or the file is     *;
%*                  versioned but no version was selected.                                       *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_getjobparameters, effective with SAS LSAF Macro 1.5              *;
%*                                                                                               *;
%* @history 2014-04-11  initial coding.                                                          *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_getjobparameters(
   sdd_path=,
   sdd_version=,
   sas_dsname=work.sddGetJobParameters
   ) /des='Get a list of the parameters for a job.';

   %****************************************;
   %* Initialize macro variables           *;
   %****************************************;
   %global _sddMsg_
           _sddRC_
   ;

   %let _sddRC_ =%str(-999);
   %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_getjobparameters(
    lsaf_path=&sdd_path,
    lsaf_version=&sdd_version,
    sas_dsname=&sas_dsname
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_getjobparameters;
