%* sasdrugdev_getobjecttype                                                                      *;
%*                                                                                               *;
%* Reports the SAS Drug Development object type for the specified                                *;
%* repository object path                                                                        *;
%*                                                                                               *;
%* The SAS macro variable _sddObjectType_ is set to the object type value.                       *;
%* The value is set to blank if the object could not be found or an error occurred.              *;
%* Possible object type values are:                                                              *;
%*    sas:analysis                                                                               *;
%*    sas:container                                                                              *;
%*    sas:file                                                                                   *;
%*    sas:folder                                                                                 *;
%*    sas:job                                                                                    *;
%*    sas:organization                                                                           *;
%*    sas:pdf                                                                                    *;
%*    sas:project                                                                                *;
%*    sas:sasdataset                                                                             *;
%*    sas:sasprogram                                                                             *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETOBJECTTYPE(SDD_PATH=sdd-path);                                                 *;
%*                                                                                               *;
%* @macvar _sddRC_         the return code.                                                      *;
%* @macvar _sddMsg_        the return message.                                                   *;
%* @macvar _sddObjectType_ the object type.                                                      *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the object for which the object type                 *;
%*                   will be retrieved.                                                          *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_getobjecttype, effective with SAS LSAF Macro 1.5                 *;
%*                                                                                               *;
%* @history 2014-03-07  initial coding                                                           *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_getobjecttype(
  sdd_path=
  ) /des='Get the SAS Drug Development object type for the specified path.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddObjectType_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_getobjecttype(lsaf_path=&sdd_path);

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=_sddObjectType_,
    lsaf_answer_val=&_lsafObjectType_
  );

%mend sasdrugdev_getobjecttype ;
