%* sasdrugdev_getowner                                                                           *;
%*                                                                                               *;
%* Returns the current owner of an object within the organization in the SAS Drug Development    *;
%* repository.                                                                                   *;
%*                                                                                               *;
%* The macro variable _sddOwner_ will be set with the owner user ID. The value of _sddOwner_     *;
%* will be <creator> for the DEFAULT permissions on a container with no specific user designated *;
%* as the owner.                                                                                 *;
%*                                                                                               *;
%* Syntax for files:                                                                             *;
%* %SASDRUGDEV_GETOWNER(SDD_PATH =sdd-path);                                                     *;
%*                                                                                               *;
%* Syntax For containers:                                                                        *;
%* %SASDRUGDEV_GETOWNER(SDD_PATH =sdd-path, SDD_ACLTYPE =sdd-acl-type);                          *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%* @macvar _sddOwner_ the current owner of the object.                                           *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the content object in the SAS Drug Development       *;
%*            repository.                                                                        *;
%* @param sdd_aclType - conditional - the type of permissions being returned.  The valid values  *;
%*            are DEFAULT and CURRENT (case-insensitive). Files only have CURRENT permissions,   *;
%*            therefore, the value is not required when sdd_path is a file. For container        *;
%*            objects the value must be specified. The operation will fail if DEFAULT is         *;
%*            requested for a file path.                                                         *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_getowner, effective with SAS LSAF Macro 1.5                      *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_getowner(
  sdd_path=,
  sdd_aclType=
  ) /des='Get the owner of an object.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddOwner_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_getowner(
    lsaf_path=&sdd_path,
    lsaf_aclType=&sdd_aclType
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=_sddOwner_,
    lsaf_answer_val=&_lsafOwner_
  );

%mend sasdrugdev_getowner;
