%* sasdrugdev_getproperties                                                                      *;
%*                                                                                               *;
%* Returns a SAS data set that contains the properties of an object in the SAS Drug Development  *;
%* repository.                                                                                   *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETPROPERTIES(SDD_PATH=sdd-path <, SDD_VERSION=sdd-version,                       *;
%*                           SAS_DSNAME=SAS-data-set>);                                          *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the object in the SAS Drug Development repository.   *;
%* @param sdd_version - optional - A specific file version. If omitted or set to blank, the      *;
%*            properties for the current file version will be returned.                          *;
%* @param sas_dsname - optional - the name of the output SAS data set that contains the metadata *;
%*            for the object specified as libref.dataset. The default value is                   *;
%*            WORK.SDDGETPROPERTIES. The data set will contain variables representing each       *;
%*            element of metadata for the object.  The data set will be sorted by the NAME       *;
%*            variable.  The following metadata will be represented in the data set.             *;
%*            - path: The path of the object                                                     *;
%*            - name: The name of the property.                                                  *;
%*            - value: The value of the property.                                                *;
%*            - displayName: The name of the property as displayed as a label within SAS Drug    *;
%*              Development. Derived properties (e.g. name, path, type) will not have a value    *;
%*              for displayName.                                                                 *;
%*            - type: The type of the property. Values include STRING, DATE, and BOOLEAN.        *;
%*              Derived properties (e.g. name, path, type) will not have a value for type.       *;
%*            - isReadonly: Flag indicating that the property cannot be modified.                *;
%*            - isExtended: Flag indicating whether the property is an extended attribute.       *;
%*                                                                                               *;
%* Note: Extended attributes are included but the names represent the system identifier. The     *;
%* recognizable label is shown in the display name variable.                                     *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_getproperties, effective with SAS LSAF Macro 1.5                 *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2014-04-18  updates to surface extended attribute metadata.                          *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%* @history 2017-01-18  added sdd_version parameter                                              *;
%*                                                                                               *;

%macro sasdrugdev_getproperties(
  sdd_path=,
  sdd_version=,
  sas_dsname=work.sddGetProperties
  ) /des='Get a list of properties for a specified object in the SAS Drug Development Repository.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_getproperties(
    lsaf_path=&sdd_path,
	lsaf_version=&sdd_version,
    sas_dsname=&sas_dsname
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_getproperties ;
