%* sasdrugdev_getrbitems                                                                         *;
%*                                                                                               *;
%* Returns a SAS data set that contains the metadata for the items in the SAS Drug Development   *;
%* recycle bin.                                                                                  *;
%*                                                                                               *;
%* Users must have the Permanent Delete Items or Restore Items Deleted by Others role privilege  *;
%* at the organization context.                                                                  *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETRBITEMS(<SAS_DSNAME=SAS-data-set>);                                            *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sas_dsname - optional - the name of the output SAS data set that will contain the      *;
%*            metadata for the items specified as libref.dataset. The default value is           *;
%*            WORK.SDDGETRBITEMS. The data set contains a row for each item in the list and      *;
%*            columns with the following names.  The data set will be sorted by path.            *;
%*            - name: The name of the item.                                                      *;
%*            - path: The path of the item.                                                      *;
%*            - objectType: Describes the type of the item (e.g. folder, data set, etc.)         *;
%*            - identifier: The unique identifier of the Repository object.                      *;
%*            - size: The size of the object in bytes (will be 0 for containers).                *;
%*            - deletedBy: The user ID that deleted the object from the Repository.              *;
%*            - deletedOn: The full date and time when the object was deleted from the Repository*;
%*                  represented as a String.                                                     *;
%*            - dateDeleted: The date when the object was deleted as a SAS Datetime format.      *;
%*            - lastModifiedBy: The user ID that last modified the object.                       *;
%*            - lastModifiedOn: The date when the object was last modified.  This value is       *;
%*                  represented as a String.                                                     *;
%*            - dateLastModified: The date when the object was last modified as a SAS Datetime   *;
%*                  format.                                                                      *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_getrbitems, effective with SAS LSAF Macro 1.5                    *;
%*                                                                                               *;
%* @history 2013-03-24  original coding.                                                         *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_getrbitems(
  sas_dsname=work.sddGetRBItems
  ) /des='Get a list of the items in the recycle bin in SAS Drug Development.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_getrbitems(sas_dsname=&sas_dsname);

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_getrbitems ;
