%* sasdrugdev_getrolemembers                                                                     *;
%*                                                                                               *;
%* Returns a SAS data set that contains the metadata for all of the members assigned to a role   *;
%* within the specified organization, project, or analysis.                                      *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETROLEMEMBERS(SDD_PATH=sdd-path, SDD_ROLE=sdd-role-name,                         *;
%* SDD_ROLE_CONTEXT=sdd-role-context,  <, SAS_DSNAME=SAS-data-set>);                             *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the context object (organization, project, or        *;
%*            analysis) where the role is assigned.                                              *;
%* @param sdd_role - required - the name of the role.                                            *;
%* @param sdd_role_context - required - specifies the context in which the role is defined as a  *;
%*            path (e.g., /SAS).                                                                 *;
%* @param sas_dsname - optional - the name of the output SAS data set that contains the metadata *;
%*            for the members specified as libref.dataset. The default value is                  *;
%*            WORK.SDDGETROLEMEMBERS. The data set contains a row for each member in the role and*;
%*            columns with the following names. The data set will be sorted by member type and   *;
%*            principalId.                                                                       *;
%*            - contextPath: The path of the context object.                                     *;
%*            - type: The member type. Valid values are user or group.                           *;
%*            - principalId: The name of the member. Valid values are group name or user ID.     *;
%*            - descriptor: The description of the member. Valid values are group name or user   *;
%*                  display name.                                                                *;
%*            - grpSrcCtxt: The context in which the group member was defined, if the member is  *;
%*                  a group.                                                                     *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_getrolemembers, effective with SAS LSAF Macro 1.5                *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_getrolemembers(
  sdd_path=,
  sdd_role=,
  sdd_role_context=,
  sas_dsname=work.sddGetRoleMembers
  ) /des='Get a list of the members of a role in an SDD context.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_getrolemembers(
    lsaf_path=&sdd_path,
    lsaf_role=&sdd_role,
    lsaf_role_context=&sdd_role_context,
    sas_dsname=&sas_dsname
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_getrolemembers;
