%* sasdrugdev_getroleprivileges                                                                  *;
%*                                                                                               *;
%* Returns a SAS data set that contains the metadata for all of the privileges assigned to a     *;
%* role within the specified organization, project, or analysis.                                 *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETROLEPRIVILEGES(SDD_PATH=sdd-path, SDD_ROLE=sdd-role-name                       *;
%* <, SAS_DSNAME=SAS-data-set>);                                                                 *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the context object (organization, project, or        *;
%*            analysis) where the role is defined.                                               *;
%* @param sdd_role - required - the name of the role.                                            *;
%* @param sas_dsname - optional - the name of the output SAS data set that will contain the      *;
%*            metadata for the privileges specified as libref.dataset. The default value is      *;
%*            WORK.SDDGETROLEPRIVILEGES. The data set contains a row for each privilege in the   *;
%*            role and columns with the following names.  The data set will be sorted by         *;
%*            privilegeId.                                                                       *;
%*            - contextPath: The path of the context object.                                     *;
%*            - roleName: The name of the role.                                                  *;
%*            - privilegeId: The identifier of the privilege.                                    *;
%*            - privilegeName: The name of the privilege.                                        *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_getroleprivileges, effective with SAS LSAF Macro 1.5             *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_getroleprivileges(
  sdd_path=,
  sdd_role=,
  sas_dsname=work.sddGetRolePrivileges
  ) /des='Get a list of the privileges of a role in an SAS Drug Development context';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_getroleprivileges(
    lsaf_path=&sdd_path,
    lsaf_role=&sdd_role,
    sas_dsname=&sas_dsname
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_getroleprivileges;
