%* sasdrugdev_getroles                                                                           *;
%*                                                                                               *;
%* Returns a SAS data set that contains the metadata for all of the roles defined and, if        *;
%* specified, inherited within the specified organization, project, or analysis.                 *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETROLES(SDD_PATH=sdd-path <,SAS_DSNAME=SAS-data-set,                             *;
%* SDD_GETINHERITED=inheritance-flag>);                                                          *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the context object (organization, project, or        *;
%*            analysis) where the roles exist.                                                   *;
%* @param sas_dsname - optional - the name of the output SAS data set that will contain the      *;
%*            metadata for the roles specified as libref.dataset. The default value is           *;
%*            WORK.SDDGETROLES. The data set contains a row for each role in the context object  *;
%*            as well as columns with the following names.  The data set will be sorted by role  *;
%*            name.                                                                              *;
%*            - path: The path of the context object.                                            *;
%*            - name: The name of the role.                                                      *;
%*            - description: The role description.                                               *;
%*            - roleSrcCtxt: The context in which the of role was defined.                       *;
%*            - isInherited: A flag indicating whether or not the role is inherited. The valid   *;
%*                  values are 0 and 1.  This variable is not included if SDD_GETINHERITED is    *;
%*                  not valid or set to 0.                                                       *;
%* @param sdd_getinherited - optional -  indicates whether or not to include inherited roles.    *;
%*            The valid values are 0 and 1 to exclude or include inherited roles respectively.   *;
%*            The default is 1.                                                                  *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_getroles, effective with SAS LSAF Macro 1.5                      *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_getroles(
  sdd_path=,
  sas_dsname=work.sddGetRoles,
  sdd_getInherited=1
  ) /des='Get a list of roles in a SAS Drug Development context.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_getroles(
    lsaf_path=&sdd_path,
    sas_dsname=&sas_dsname,
    lsaf_getInherited=&sdd_getInherited
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_getroles;
