%* sasdrugdev_getsignatures                                                                      *;
%*                                                                                               *;
%* Returns a SAS data set that contains the metadata for all of the signatures of a file or a    *;
%* specific version of the file.                                                                 *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETSIGNATURES(SDD_PATH=sdd-path <, SDD_VERSION=sdd-version,                       *;
%*       SAS_DSNAME=SAS-data-set>);                                                              *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required -the path of the file in the SAS Drug Development repository.      *;
%* @param sdd_version - optional - a specific version number of the file. If not specified,      *;
%*            the signatures of all versions of the file will be returned. Specifying a version  *;
%*            for a non-versioned job will cause an error.                                       *;
%* @param sas_dsname - optional - the name of the output SAS data set that will contain the      *;
%*            metadata for the signatures specified as libref.dataset. The default value is      *;
%*            WORK.SDDGETSIGNATURES. The data set contains a row for each signature for file     *;
%*            and/or version specified and columns with the following names.  The data set is    *;
%*            sorted by descending date of signature.                                            *;
%*            - name: The name of the file.                                                      *;
%*            - path: The path of the file.                                                      *;
%*            - objectType: The type of file (i.e., data set, program, etc.).                    *;
%*            - versionLabel: The label associated with this specific version.                   *;
%*            - userId: The unique login identifier for the signer of the file.                  *;
%*            - dateTimeStamp: The date and time of the signature represented as a string.       *;
%*            - dateSigned: The date and time of the signature as a SAS Datetime format.         *;
%*            - reason: The reason specified when the file was signed.                           *;
%*            - role: The role specified when the file was signed.                               *;
%*            - comment: The comment that was entered when the file was signed.                  *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_getsignatures, effective with SAS LSAF Macro 1.5                 *;
%*                                                                                               *;
%* @history 2014-02-25  initial coding.                                                          *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_getsignatures(
  sdd_path=,
  sdd_version=,
  sas_dsname=work.sddGetSignatures
  ) /des='Get a list of all the signatures of a file in the SAS Drug Development in the repository.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_getsignatures(
    lsaf_path=&sdd_path,
    lsaf_version=&sdd_version,
    sas_dsname=&sas_dsname
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_getsignatures ;
