%* sasdrugdev_getsubmissionstatus                                                                *;
%*                                                                                               *;
%* Determines the status of a SAS Drug Development repository or workspace job submission.       *;
%*                                                                                               *;
%* The SAS macro variable _sddJobSubmissionStatus_ is set to the status value. The values are    *;
%* NOT_DETERMINED, NOT_STARTED, STARTED, COMPLETED.                                              *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETSUBMISSIONSTATUS(SDD_JOBSUBMISSION_ID=job-submission-id);                      *;
%*           <, SDD_VERSION=sdd-version> );                                                      *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%* @macvar _sddJobSubmissionStatus_ indicates the job submission status.                         *;
%*                                                                                               *;
%* @param sdd_jobsubmission_id - required - the submission identifier returned from the          *;
%*         sasdrugdev_submitjob macro.                                                           *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_getsubmissionstatus, effective with SAS LSAF Macro 1.5           *;
%*                                                                                               *;
%* @history 2014-04-07  initial code                                                             *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_getsubmissionstatus(
  sdd_jobsubmission_id=
  ) /des='What is the submission status of SAS Drug Development job?';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddJobSubmissionStatus_
          _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_getsubmissionstatus(lsaf_jobsubmission_id=&sdd_jobsubmission_id);

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=_sddJobSubmissionStatus_,
    lsaf_answer_val=&_lsafJobSubmissionStatus_
  );

%mend sasdrugdev_getsubmissionstatus;
