%* sasdrugdev_getsubscriptions                                                                   *;
%*                                                                                               *;
%* Returns a SAS data set containing metadata for all subscriptions for the current user.        *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETSUBSCRIPTIONS(<SAS_DSNAME=SAS-data-set>);                                      *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sas_dsname - optional - the name of the output SAS data set that will contain the      *;
%*            metadata for the subscriptions specified as libref.dataset. The default value is   *;
%*            WORK.SDDGETSUBSCRIPTIONS. The data set contains a row for each subscription        *;
%*            with the following names.  The data set will be sorted by event, location, and     *;
%*            principalId.                                                                       *;
%*            - event: The name of the event subscription.                                       *;
%*            - location: The path of the object to which a subscription applies.                *;
%*            - type:  The subscriber type.  Values are USER and GROUP.                          *;
%*            - cascade: Indicates if the subscription is cascaded to child items.  Values are   *;
%*                  0 and 1.                                                                     *;
%*            - principalId: The id of the subscriber.  The returned values will be either a     *;
%*                  group name or the user ID of the current user.                               *;
%*            - grpSrcCtxt: The context path in which the group was defined if the subscription  *;
%*                  is a for group.                                                              *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_getsubscriptions, effective with SAS LSAF Macro 1.5              *;
%*                                                                                               *;
%* @history 2014-03-11  initial coding                                                           *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_getsubscriptions(
  sas_dsname=work.sddGetSubscriptions
  ) /des='Get a list of subscriptions for the current user';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_getsubscriptions(sas_dsname=&sas_dsname);

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_getsubscriptions;
