%* sasdrugdev_getsyncstatus                                                                      *;
%*                                                                                               *;
%* Determines if a file in the SAS Drug Development repository is synchronized, out of           *;
%* synchronization, or has never been synchronized with the workspace.                           *;
%*                                                                                               *;
%* The SAS macro variable _sddSyncStatus_ is set to the status value. The values are NOT_SYNCED, *;
%* IN_SYNC, and OUT_OF_SYNC.  If the file does not exist in either the workspace or the          *;
%* repository, the status is reported as NOT_SYNCED. If the object is a container, an error will *;
%* be reported.                                                                                  *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETSYNCSTATUS(SDD_PATH=sdd-path);                                                 *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%* @macvar _sddSyncStatus_ indicates the syncronization status.                                  *;
%*                                                                                               *;
%* @param sdd_path - required -  the path of the file.                                           *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_getsyncstatus, effective with SAS LSAF Macro 1.5                 *;
%*                                                                                               *;
%* @history 2014-04-07  initial code                                                             *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_getsyncstatus(
  sdd_path=
  ) /des='What is the synchronization status of SAS Drug Development file?';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddSyncStatus_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_getsyncstatus(lsaf_path=&sdd_path);

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=_sddSyncStatus_,
    lsaf_answer_val=&_lsafSyncStatus_
  );

%mend sasdrugdev_getsyncstatus ;
