%* sasdrugdev_getusergroups                                                                      *;
%*                                                                                               *;
%* Returns a SAS data set containing metadata for each of the groups in which the specified      *;
%* user is a member.                                                                             *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETUSERGROUPS(SDD_USERID=sdd-userid <, SAS_DSNAME=SAS-data-set>);                 *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%* @param sdd_userid - required - the user ID of the user for which groups will be retrieved.    *;
%* @param sas_dsname - optional - the name of the output SAS data set that will contain the      *;
%*            metadata for the groups specified as libref.dataset. The default value is          *;
%*            WORK.SDDGETUSERGROUPS. The data set contains a row for each group and columns      *;
%*            with the following names.  The data set will be sorted by group name and           *;
%*            group context path.                                                                *;
%*            - userId: The user ID of the user.                                                 *;
%*            - name: The name of the group.                                                     *;
%*            - description: The description of the group.                                       *;
%*            - grpSrcCtxt: The context path where the group was defined.                        *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_getusergroups, effective with SAS LSAF Macro 1.5                 *;
%*                                                                                               *;
%* @history 2014-03-20  initial coding                                                           *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_getusergroups(
  sdd_userid=,
  sas_dsname=work.sddGetUserGroups
  ) /des='Get a list of the groups in which a user is a member.';


  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_getusergroups(
    lsaf_userid=&sdd_userid,
    sas_dsname=&sas_dsname
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_getusergroups;
