%* sasdrugdev_getuserprivileges                                                                  *;
%*                                                                                               *;
%* Returns a SAS data set that contains the metadata for all of the global privileges assigned   *;
%* to a user within the system.                                                                  *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETUSERPRIVILEGES(SDD_USERID=sdd-userid <, SAS_DSNAME=SAS-data-set>);             *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_userid - required - the user to retrieve the global privileges for.                *;
%* @param sas_dsname - optional - the name of the output SAS data set that will contain the      *;
%*            metadata for the global privileges specified as libref.dataset. The default value  *;
%*            is WORK.SDDGETUSERPRIVILEGES. The data set contains a row for each global privilege*;
%*            assigned to the user and the columns with the following names.  The data set will  *;
%*            be sorted by privilegeId.                                                          *;
%*            - userId: The user ID of the user.                                                 *;
%*            - privilegeId: The identifier of the privilege.                                    *;
%*            - privilegeName: The name of the privilege.                                        *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.3                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_getuserprivileges, effective with SAS LSAF Macro 1.5             *;
%*                                                                                               *;
%* @history 2013-11-01 initial coding                                                            *;
%* @history 2016-08-31 rebrand for LSAF                                                          *;
%*                                                                                               *;

%macro sasdrugdev_getuserprivileges(
  sdd_userid=,
  sas_dsname=work.sddGetUserPrivileges
  ) /des='Get a list of the global privileges assigned to a user.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_getuserprivileges(
    lsaf_userid=&sdd_userid,
    sas_dsname=&sas_dsname
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_getuserprivileges;
