%* sasdrugdev_getversions                                                                        *;
%*                                                                                               *;
%* Returns a SAS data set that contains the metadata for all of the versions of a file.          *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GETVERSIONS(SDD_PATH=sdd-path <, SAS_DSNAME=SAS-data-set>);                       *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required -the path of the object in the SAS Drug Development repository.    *;
%* @param sas_dsname - optional - the name of the output SAS data set that will contain the      *;
%*            metadata for the versions specified as libref.dataset. The default value is        *;
%*            WORK.SDDGETVERSIONS. The data set contains a row for each version of the object    *;
%*            and columns with the following names.  The most recent version will be the first   *;
%*            observation in the data set.                                                       *;
%*            - name: The name of the object.                                                    *;
%*            - path: The path of the object.                                                    *;
%*            - objectType: The type of file (i.e., data set, program, etc.).                    *;
%*            - description: The description of the object.                                      *;
%*            - versionLabel: The label associated with this specific version.                   *;
%*            - isCheckedOut: A numeric flag that indicates whether the object is currently      *;
%*                  checked out (0=no, 1=yes).                                                   *;
%*            - isLocked:  A numeric flag that indicates whether the object is currently locked  *;
%*                  (0=no, 1=yes).                                                               *;
%*            - size: The size of the object in bytes (will be 0 for containers).                *;
%*            - contentType: The content or MIME type of object.                                 *;
%*            - createdBy: The user ID that created the object.                                  *;
%*            - created: The full date and time the object was created represented as a string.  *;
%*            - dateCreated: The date the object was created as a SAS Datetime format.           *;
%*            - lastModifiedBy: The user ID that last modified the object.                       *;
%*            - lastModified: The date the object was last modified represented as a string.     *;
%*            - dateLastModified: The date the object was last modified as a SAS Datetime format.*;
%*            - propertiesLastModifiedBy: The user ID that last modified the properties for the  *;
%*                  object.                                                                      *;
%*            - propertiesLastModified: The date when the object properties were last modified.  *;
%*                  This value is represented as a String.                                       *;
%*            - datePropertiesLastModified: The date when the object properties were last        *;
%*                  modified as a SAS Datetime format.                                           *;
%*            - isSigned: Indicates if the object has electronic signatures attached to it.      *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_getversions, effective with SAS LSAF Macro 1.5                   *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2014-05-07  updated documentation and fixed data set processing.                     *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_getversions(
  sdd_path=,
  sas_dsname=work.sddGetVersions
  ) /des='Get a list of all the versions of an object in the SAS Drug Development in the repository.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_getversions(
    lsaf_path=&sdd_path,
    sas_dsname=&sas_dsname
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_getversions ;
