%* sasdrugdev_groupexists                                                                        *;
%*                                                                                               *;
%* Determines whether a group is defined for the specified context.                              *;
%*                                                                                               *;
%* The macro variable _sddGroupExists_ will be set to 1 if the group exists, 0 if it does not.   *;
%* In the event of an incorrect call to the macro which results in an error, the return value    *;
%* of _sddGroupExists_ will be set to -1.                                                        *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_GROUPEXISTS (SDD_PATH=sdd-path, SDD_GROUP=sdd- name);                             *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%* @macvar _sddGroupExists_ indicates if the group exists in the context.                        *;
%*                                                                                               *;
%* @param sdd_path - required -  the path of the context object.                                 *;
%* @param sdd_group - required - the name of the group.                                          *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_groupexists, effective with SAS LSAF Macro 1.5                   *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_groupexists(
  sdd_path=,
  sdd_group=
  ) /des='Is the group defined in the context.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddGroupExists_
          _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_groupexists(
    lsaf_path=&sdd_path,
    lsaf_group=&sdd_group
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=_sddGroupExists_,
    lsaf_answer_val=&_lsafGroupExists_
  );

%mend sasdrugdev_groupexists ;
