%* sasdrugdev_iscontainer                                                                        *;
%*                                                                                               *;
%* Determines whether a SAS Drug Development repository object is of type container.             *;
%*                                                                                               *;
%* The SAS macro variable _sddIsContainer_ is set to a value of 1 if the specified object is a   *;
%* container object, 0 if it is not. In the event of an incorrect call to the macro which        *;
%* results in an error, the return value of _sddIsContainer_ will be set to -1.                  *;
%* Container objects include folders, projects, analyses, and the organization.                  *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_ISCONTAINER(SDD_PATH=sdd-path);                                                   *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%* @macvar _sddIsContainer_ indicates if the object is a container.                              *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the object in the SAS Drug Development repository.   *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_iscontainer, effective with SAS LSAF Macro 1.5                   *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_iscontainer(
  sdd_path=
  ) /des='Is the object a container?';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddIsContainer_
          _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_iscontainer(lsaf_path=&sdd_path);

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=_sddIsContainer_,
    lsaf_answer_val=&_lsafIsContainer_
  );

%mend sasdrugdev_iscontainer;
