%* sasdrugdev_ismember                                                                           *;
%*                                                                                               *;
%* Determines whether a user or group is a member in the specified organization, project,        *;
%* or analysis.                                                                                  *;
%*                                                                                               *;
%* The SAS macro variable _sddIsMember_ is set to a value of 1 when the specified user or group  *;
%* is a member of the context, 0 if it is not. In the event of an incorrect call to the macro    *;
%* which results in an error, the return value of _sddIsMember_ will be set to -1.               *;
%* Groups defined at the context level will not be considered as members of that context.        *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_ISMEMBER(SDD_PATH=sdd-path, SDD_MEMBER=sdd-member-identifier <, SDD_TYPE=sdd-type,*;
%* SDD_GROUP_CONTEXT=sdd-group-context>);                                                        *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%* @macvar _sddIsMember_ indicates if the user or group is a member of the specified             *;
%*            organization, project, or analysis.                                                *;
%*                                                                                               *;
%* @param sdd_path - required -  the path (starting at the root) context object (organization,   *;
%*            project, or analysis).                                                             *;
%* @param sdd_member - required - the user ID or group name of the member.                       *;
%* @param sdd_type - conditional - indicates the type of member. Valid values are USER and GROUP *;
%*            (case-insensitive).  The default value is USER.                                    *;
%* @param sdd_group_context - conditional - specifies the context in which the member group is   *;
%*            defined as a path (e.g., /SAS). The parameter is required if SDD_TYPE=GROUP.       *;
%*            Otherwise, it will be ignored.                                                     *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_ismember, effective with SAS LSAF Macro 1.5                      *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_ismember(
  sdd_path=,
  sdd_member=,
  sdd_type=USER,
  sdd_group_context=
  ) /des='Is the user or group a member in the specified context?';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddIsMember_
          _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_ismember(
    lsaf_path=&sdd_path,
    lsaf_member=&sdd_member,
    lsaf_type=&sdd_type,
    lsaf_group_context=&sdd_group_context
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=_sddIsMember_,
    lsaf_answer_val=&_lsafIsMember_
  );

%mend sasdrugdev_ismember ;
