%* sasdrugdev_isrolemember                                                                       *;
%*                                                                                               *;
%* Determines whether a user or group is a member of a role in the specified organization,       *;
%* project, or analysis.                                                                         *;
%*                                                                                               *;
%* The SAS macro variable _sddIsRoleMember_ is set to a value of 1 when the specified user or    *;
%* group is a member of the role, 0 if it is not. In the event of an incorrect call to the macro *;
%* which results in an error, the return value of _sddIsRoleMember_ will be set to -1.           *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_ISROLEMEMBER(SDD_PATH=sdd-path, SDD_ROLE=sdd-role-name,                           *;
%* SDD_ROLE_CONTEXT=sdd-role-context, SDD_MEMBER=sdd-member-identifier <, SDD_TYPE=sdd-type,     *;
%* SDD_GROUP_CONTEXT=sdd-group-context>);                                                        *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%* @macvar _sddIsRoleMember_ indicates if the user or group is a member of the role in the       *;
%*            specified organization, project, or analysis.                                      *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the context object (organization, project, or        *;
%*            analysis) where the role is assigned.                                              *;
%* @param sdd_role - required - the name of the role.                                            *;
%* @param sdd_role_context - required - the context in which the role is defined as a path       *;
%*            (e.g., /SAS).                                                                      *;
%* @param sdd_member - required - the user ID or group name of the member.                       *;
%* @param sdd_type - conditional - indicates the type of member. Valid values are USER and GROUP *;
%*            (caes-insensitive).  The default value is USER.                                    *;
%* @param sdd_group_context - conditional - specifies the context in which the member group is   *;
%*            defined as a path (e.g., /SAS). The parameter is required if SDD_TYPE=GROUP.       *;
%*            Otherwise, it will be ignored.                                                     *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_isrolemember, effective with SAS LSAF Macro 1.5                  *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_isrolemember(
  sdd_path=,
  sdd_role=,
  sdd_role_context=,
  sdd_member=,
  sdd_type=USER,
  sdd_group_context=
  ) /des='Is the user or group a member of the role in the specified context?';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddIsRoleMember_
          _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_isrolemember(
    lsaf_path=&sdd_path,
    lsaf_role=&sdd_role,
    lsaf_role_context=&sdd_role_context,
   lsaf_member=&sdd_member,
   lsaf_type=&sdd_type,
    lsaf_group_context=&sdd_group_context
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=_sddIsRoleMember_,
    lsaf_answer_val=&_lsafIsRoleMember_
  );

%mend sasdrugdev_isrolemember ;
