%* sasdrugdev_isroleprivilege                                                                    *;
%*                                                                                               *;
%* Determines whether a privilege is assigned to a role in the specified organization,           *;
%* project, or analysis. Works only for defined roles, not inherited roles, in the specified     *;
%* organization, project, or analysis.                                                           *;
%*                                                                                               *;
%* The SAS macro variable _sddIsRolePrivilege_ is set to a value of 1 when the privilege is      *;
%* assigned, 0 if it is not. In the event of an incorrect call to the macro which results in an  *;
%* error, the return value of _sddIsRolePrivilege_ will be set to -1.                            *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_ISROLEPRIVILEGE(SDD_PATH=sdd-path, SDD_ROLE=sdd-role-name,                        *;
%* SDD_PRIVILEGE=sdd-privilege-id);                                                              *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%* @macvar _sddIsRolePrivilege_ indicates if the privilege is assigned to the role in the        *;
%*            specified organization, project, or analysis.                                      *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the context object (organization, project, or        *;
%*            analysis) where the role is assigned.                                              *;
%* @param sdd_role - required - the name of the role.                                            *;
%* @param sdd_privilege - required - the identifier of the privilege to check.                   *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_isroleprivilege, effective with SAS LSAF Macro 1.5               *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_isroleprivilege(
  sdd_path=,
  sdd_role=,
  sdd_privilege=
  ) /des='Is the privilege in the role in the specified context?';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddIsRolePrivilege_
          _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_isroleprivilege(
    lsaf_path=&sdd_path,
    lsaf_role=&sdd_role,
    lsaf_privilege=&sdd_privilege
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=_sddIsRolePrivilege_,
    lsaf_answer_val=&_lsafIsRolePrivilege_
  );

%mend sasdrugdev_isroleprivilege ;
