%* sasdrugdev_isuserprivilege                                                                    *;
%*                                                                                               *;
%* Determines whether a global privilege is assigned to a user.                                  *;
%*                                                                                               *;
%* The SAS macro variable _sddIsUserPrivilege_ is set to a value of 1 when the privilege is      *;
%* assigned, 0 if it is not. In the event of an incorrect call to the macro which results in an  *;
%* error, the return value of _sddIsUserPrivilege_ will be set to -1.                            *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_ISUSERPRIVILEGE(SDD_USERID=sdd-userid, SDD_PRIVILEGE=sdd-privilege-id);           *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%* @macvar _sddIsUserPrivilege_ indicates if the privilege is assigned to the user.              *;
%*                                                                                               *;
%* @param sdd_userid - required - the user ID to check.                                          *;
%* @param sdd_privilege - required - the identifier of the global privilege to check.            *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.3                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_isuserprivilege, effective with SAS LSAF Macro 1.5               *;
%*                                                                                               *;
%* @history 2013-11-01 initial coding                                                            *;
%* @history 2016-08-31 rebrand for LSAF                                                          *;
%*                                                                                               *;

%macro sasdrugdev_isuserprivilege(
  sdd_userid=,
  sdd_privilege=
  ) /des='Is the global privilege assigned to the specified user?';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddIsUserPrivilege_
          _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_isuserprivilege(
    lsaf_userid=&sdd_userid,
    lsaf_privilege=&sdd_privilege
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=_sddIsUserPrivilege_,
    lsaf_answer_val=&_lsafIsUserPrivilege_
  );

%mend sasdrugdev_isuserprivilege ;
