%* sasdrugdev_isversioned                                                                        *;
%*                                                                                               *;
%* Determines whether a SAS Drug Development repository object has versioning enabled.           *;
%*                                                                                               *;
%* The SAS macro variable _sddIsVersioned_ is set to a value of 1 when the object is versioned,  *;
%* 0 if it is not. In the event of an incorrect call to the macro which results in an error,     *;
%* the return value of _sddIsVersioned_ will be set to -1.                                       *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_ISVERSIONED(SDD_PATH=sdd-path);                                                   *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%* @macvar _sddIsVersioned_ indicates if the object is versioned or not.                         *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the file.                                            *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.1                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_isversioned, effective with SAS LSAF Macro 1.5                   *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_isversioned(
  sdd_path=
  ) /des='Does the file in the repository have versioning enabled?';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddIsVersioned_
          _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_isversioned(lsaf_path=&sdd_path);

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=_sddIsVersioned_,
    lsaf_answer_val=&_lsafIsVersioned_
  );

%mend sasdrugdev_isversioned ;
