%* sasdrugdev_login                                                                              *;
%*                                                                                               *;
%* Creates a connection to the SAS Drug Development instance.                                    *;
%*                                                                                               *;
%* This macro is only required when running the macros from a PC SAS session. It must be called  *;
%* before any other SAS Drug Development macro in order to establish your session.               *;
%*                                                                                               *;
%* NOTE: This macro is only supported from a PC SAS session. Using this macro within an active   *;
%* SAS Drug Development application session will result in a failure.                            *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_LOGIN(SDD_URL=url, SDD_USERID=user-id , SDD_PASSWORD=password,                    *;
%*            <, PROXY_HOST=proxy-host, PROXY_USERID=proxy-userid, PROXY_PASSWORD=proxy-pw );    *;
%*                                                                                               *;
%* Example Code:                                                                                 *;
%*                                                                                               *;
%* 1. The parameters passed to the login macro are often strings containing special characters   *;
%*    which may cause problems when resolved by SAS.  You will probably want to wrap each of the *;
%*    parameters in a SAS function call to prevent any issues:                                   *;
%*    %sasdrugdev_login(sdd_url=%str(https://sddinstance), sdd_userid=%str(sdd-user-id),         *;
%*    sdd_password=%str (sddpassword ));                                                         *;
%*                                                                                               *;
%* 2. Certain special characters common in passwords (e.g. ampersands, percent signs) may        *;
%*    may require quoting.                                                                       *;
%*    %sasdrugdev_login(sdd_url=%str(https://sddinstance), sdd_userid=%str(sdd-user-id),         *;
%*    sdd_password=%nrbquote(sddpassword ));                                                     *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_url - required - the URL of the SAS Drug Development instance to use in the form   *;
%*            https://sddname.sas.com or http://sddname.sas.com.                                 *;
%* @param sdd_userid - required - the SAS Drug Development ID for the user account.              *;
%* @param sdd_password - required - the SAS Drug Development password for the user account.      *;
%* @param proxy_host - conditional - the name of the host machine when the SAS Drug Development  *;
%*             system is accessed through a proxy server.                                        *;
%* @param proxy_port - conditional - the port number required for the proxy host machine.        *;
%*             Required when a proxy_host is designated.                                         *;
%* @param proxy_userid - conditional - the userid when the proxy machine requires authentication.*;
%* @param proxy_password - conditional - the password when the proxy machine required            *;
%*             authentication.                                                                   *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.1                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_login, effective with SAS LSAF Macro 1.5                         *;
%*                                                                                               *;
%* @history 2013-06-26  version 1.2 update - trusted session                                     *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2014-03-04  updates for proxy                                                        *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_login(
  sdd_url=,
  sdd_userid=,
  sdd_password=,
  proxy_host=,
  proxy_port=,
  proxy_userid=,
  proxy_password=
  ) /des='Initialize connection to SAS Drug Development.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_login(
    lsaf_url=&sdd_url,
    lsaf_userid=&sdd_userid,
    lsaf_password=&sdd_password,
    proxy_host=&proxy_host,
    proxy_port=&proxy_port,
    proxy_userid=&proxy_userid,
    proxy_password=&proxy_password
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_login ;
