%* sasdrugdev_logout                                                                             *;
%*                                                                                               *;
%* Closes an open connection to SAS Drug Development.                                            *;
%*                                                                                               *;
%* This macro is only used when running the macros from a PC SAS session. This should be the     *;
%* last macro you call in any program.                                                           *;
%*                                                                                               *;
%* NOTE: This macro is only supported from a PC SAS session. Using this macro within an active   *;
%* SAS Drug Development application session will result in a failure.                            *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_LOGOUT();                                                                         *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.1                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_logout, effective with SAS LSAF Macro 1.5                        *;
%*                                                                                               *;
%* @history 2013-06-26  version 1.2 update - trusted session                                     *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-31  rebrand as LSAF                                                          *;
%*                                                                                               *;

%macro sasdrugdev_logout(
  ) /des='Terminate the connection to SAS Drug Development.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_logout();

  %let sddMacroName_=SASDRUGDEV_LOGOUT;
  %let lsafMacroName_=LSAF_LOGOUT;

  %if %symexist(_lsafRC_) %then
  %do;
    %***************************************;
    %* Call LSAF transition code           *;
    %***************************************;
    %lsaf_transition(
      sdd_macro_name=%lowcase(&sddMacroName_),
      sdd_answer_var=,
      lsaf_answer_val=
    );
  %end;
  %else
  %do;
    %***********************************************;
    %* Clear all _SDD* macro variables on LOGOUT   *;
	%*                                             *;
    %* Retain original value for source and notes  *;
    %* option then turn source and notes off       *;
    %***********************************************;
	%let sourceOption=%sysfunc(getoption(source));
    %let notesOption=%sysfunc(getoption(notes));

	%*********************************************;
    %* Rebrand message for SASDRUGDEV API macros *;
    %*********************************************;
    %put;
    %put NOTE: ***********************************************************************************;
    %put NOTE: The %upcase(&sddmacroname_) macro will be deprecated in the next release of        ;
    %put NOTE: SAS Life Science Analytics Framework and replaced with %upcase(&lsafmacroname_).   ;
    %put NOTE: ***********************************************************************************;
    %put;

    options nosource nonotes;

    data mvarstable;
     set sashelp.vmacro;
    run;

    data _null_;
      set mvarstable;
      pos=index(name,'_SDD');
      if (pos=1);
      message="Deleting macro variable " || strip(name) || " from scope " || strip(scope) || ".";
      put message;
      call execute('%symdel ' || strip(name) || '; ');
    run;

    %*********************************;
    %* reset source and notes option *;
    %*********************************;
    options &sourceOption &notesOption;
   %end;

%mend sasdrugdev_logout ;
