%* sasdrugdev_move                                                                               *;
%*                                                                                               *;
%* Moves a file or folder to the specified target location.                                      *;
%*                                                                                               *;
%* The item being moved must not already exist in the target location.                           *;
%* The children of a moved folder will also be moved to the target location,                     *;
%* keeping their directory structure and version history (if any) intact.                        *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_MOVE(SDD_SOURCE=sdd-source-path, SDD_TARGET=sdd-target-path);                     *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_source - required - the path of the object to be moved.                            *;
%* @param sdd_target - required - the path of the folder into which the object is to be          *;
%*            moved. The target folder must already exist. Path cannot end with a slash (/).     *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_move, effective with SAS LSAF Macro 1.5                          *;
%*                                                                                               *;
%* @history 2014-03-03  initial coding                                                           *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_move(
  sdd_source=,
  sdd_target=
  ) /des='Move a file or folder.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_move(
    lsaf_source=&sdd_source,
    lsaf_target=&sdd_target
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_move ;
