%* sasdrugdev_objectexists                                                                       *;
%*                                                                                               *;
%* Determines whether a SAS Drug Development repository object exists.                           *;
%*                                                                                               *;
%* The SAS macro variable _sddObjectExists_ is set to a value of 1 when the object exits, 0 if   *;
%* it does not. In the event of an incorrect call to the macro which results in an error, the    *;
%* return value of _sddObjectExists_ will be set to -1.                                          *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_OBJECTEXISTS(SDD_PATH=sdd-path);                                                  *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%* @macvar _sddObjectExists_ indicates if the object exists.                                     *;
%*                                                                                               *;
%* @param sdd_path - required -  the path of the object.                                         *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.1                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_objectexists, effective with SAS LSAF Macro 1.5                  *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-30  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_objectexists(
  sdd_path=
  ) /des='Does the object exist in the repository?';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddObjectExists_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_objectexists(lsaf_path=&sdd_path);

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=_sddObjectExists_,
    lsaf_answer_val=&_lsafObjectExists_
  );

%mend sasdrugdev_objectexists ;
