%* sasdrugdev_removemember                                                                       *;
%*                                                                                               *;
%* Removes a user or a group as a member of the specified organization, project, or analysis.    *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_REMOVEMEMBER(SDD_PATH=sdd-path, SDD_MEMBER=sdd-member-identifier                  *;
%* <, SDD_TYPE=sdd-type, SDD_GROUP_CONTEXT=sdd-group-context>);                                  *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the context object (organization, project, or        *;
%*            analysis) to remove the member from.                                               *;
%* @param sdd_member - required - the id of the user or the name of the group being removed.     *;
%* @param sdd_type - conditional - indicates the type of member. Valid values are USER and GROUP *;
%*            (case-insensitive).  The default value is USER.                                    *;
%* @param sdd_group_context - conditional - specifies the context in which the group being       *;
%*            removed is defined as a path (e.g., /SAS). This parameter is required if           *;
%*            SDD_TYPE=GROUP. Otherwise, it will be ignored.                                     *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_removemember, effective with SAS LSAF Macro 1.5                  *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_removemember(
  sdd_path=,
  sdd_member=,
  sdd_type=USER,
  sdd_group_context=
  ) /des='Remove a member from the context.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_removemember(
    lsaf_path=&sdd_path,
    lsaf_member=&sdd_member,
    lsaf_type=&sdd_type,
    lsaf_group_context=&sdd_group_context
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_removemember ;
