%* sasdrugdev_removerolemember                                                                   *;
%*                                                                                               *;
%* Removes a user or a group as a member of a role in the specified organization, project, or    *;
%* analysis.                                                                                     *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_REMOVEROLEMEMBER(SDD_PATH=sdd-path, SDD_ROLE=sdd-role-name,                       *;
%* SDD_ROLE_CONTEXT=sdd-role-context, SDD_MEMBER=sdd-member-identifier <, SDD_TYPE=sdd-type,     *;
%* SDD_GROUP_CONTEXT=sdd-group-context>);                                                        *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the context object (organization, project, or        *;
%*            analysis) where the role is assigned.                                              *;
%* @param sdd_role - required - the name of the role that the member is to be removed from.      *;
%* @param sdd_role_context - required - specifies the context in which the role is defined as a  *;
%*            path (e.g., /SAS).                                                                 *;
%* @param sdd_member - required - the ID of the user or the name of the group being removed.     *;
%* @param sdd_type - conditional - indicates the type of member. Valid values are USER and GROUP *;
%*            (case-insensitive).  The default value is USER.                                    *;
%* @param sdd_group_context - conditional - specifies the context in which the group being       *;
%*            removed is defined as a path (e.g., /SAS). This parameter is required if           *;
%*            SDD_TYPE=GROUP. Otherwise, it will be ignored.                                     *;
%*                                                                                               *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_removerolemember, effective with SAS LSAF Macro 1.5              *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_removerolemember(
  sdd_path=,
  sdd_role=,
  sdd_role_context=,
  sdd_member=,
  sdd_type=USER,
  sdd_group_context=
  ) /des='Remove a member from a role in the specified context.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_removerolemember(
    lsaf_path=&sdd_path,
    lsaf_role=&sdd_role,
    lsaf_role_context=&sdd_role_context,
    lsaf_member=&sdd_member,
    lsaf_type=&sdd_type,
    lsaf_group_context=&sdd_group_context
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_removerolemember;
