%* sasdrugdev_removeroleprivilege                                                                *;
%*                                                                                               *;
%* Removes a privilege from a role in the specified organization, project, or analysis.          *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_REMOVEROLEPRIVILEGE(SDD_PATH=sdd-path, SDD_ROLE=sdd-role-name,                    *;
%* SDD_PRIVILEGE=sdd-privilege-id);                                                              *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the context object (organization, project, or        *;
%*            analysis) where the role is defined.                                               *;
%* @param sdd_role - required - the name of the role that the privilege is to be removed from.   *;
%* @param sdd_privilege - required - the identifier of the privilege to remove.                  *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_removeroleprivilege, effective with SAS LSAF Macro 1.5           *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_removeroleprivilege(
  sdd_path=,
  sdd_role=,
  sdd_privilege=
  ) /des='Remove a privilege from a role in the specified context.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_removeroleprivilege(
    lsaf_path=&sdd_path,
    lsaf_role=&sdd_role,
    lsaf_privilege=&sdd_privilege
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_removeroleprivilege;
