%* sasdrugdev_resetpassword                                                                      *;
%*                                                                                               *;
%* Reset the password for a user in the system.  This action requires the logged on user to have *;
%* the administrative privilege PRIVILEGE_MANAGE_USER_ACCOUNTS.  Once the password has been      *;
%* successfully reset, the user can immediately log on with the new password, but they will be   *;
%* forced to change their password immediately so the password remains unique to the user.       *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_RESETPASSWORD(SDD_USERID=sdd-userid, SDD_NEWPASSWORD=sdd-password);               *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_userid - required - the user ID of the account to reset.                           *;
%* @param sdd_newpassword - required - the new temporary password.                               *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.3                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_resetpassword, effective with SAS LSAF Macro 1.5                 *;
%*                                                                                               *;
%* @history 2013-11-04 initial coding                                                            *;
%* @history 2016-08-31 rebrand for LSAF                                                          *;
%*                                                                                               *;

%macro sasdrugdev_resetpassword(
  sdd_userid=,
  sdd_newpassword=
  ) /des='Reset the password for an account in the system.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_resetpassword(
    lsaf_userid=&sdd_userid,
    lsaf_newpassword=&sdd_newpassword
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_resetpassword;
