%* sasdrugdev_roleexists                                                                         *;
%*                                                                                               *;
%* Determines whether a a role is defined in the specified organization, project, or analysis.   *;
%*                                                                                               *;
%* The SAS macro variable _sddRoleExists_ is set to a value of 1 when the role exists, 0 if it   *;
%* is not. In the event of an incorrect call to the macro which results in an error, the return  *;
%* value of _sddRoleExists_ will be set to -1.                                                   *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_ROLEEXISTS(SDD_PATH=sdd-path, SDD_ROLE=sdd-role-name);                            *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%* @macvar _sddRoleExists_ indicates if the role exists in the context.                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the context object (organization, project, or        *;
%*            analysis).                                                                         *;
%* @param sdd_role - required - the name of the role.                                            *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_roleexists, effective with SAS LSAF Macro 1.5                    *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_roleexists(
  sdd_path=,
  sdd_role=
  ) /des='Is the role defined in the context?';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
          _sddRoleExists_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_roleexists(
    lsaf_path=&sdd_path,
    lsaf_role=&sdd_role
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=_sddRoleExists_,
    lsaf_answer_val=&_lsafRoleExists_
  );

%mend sasdrugdev_roleexists ;
