%* sasdrugdev_syncfiletoworkspace                                                                *;
%*                                                                                               *;
%* Gets the version of the SAS Drug Development from the repository file to the workspace.       *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_SYNCFILETOWORKSPACE(SDD_PATH=sdd-path, SDD_VERSION=sdd-version>);                 *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the file within the SAS Drug Development repository  *;
%*            to download.                                                                       *;
%* @param sdd_version - conditional - specifies the version of the file to be synchronized if    *;
%*            the file is versioned.  If the file is versioned and a version is specified the    *;
%*            value must be in the valid format including a decimal point such as 1.0 or 4.2.    *;
%*            If the file is versioned and no version is specified the latest version is         *;
%*            downloaded.  If the file is unversioned and a version is specified, the value will *;
%*            be ignored.                                                                        *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_syncfiletoworkspace, effective with SAS LSAF Macro 1.5           *;
%*                                                                                               *;
%* @history 2014-04-07 initial coding                                                            *;
%* @history 2016-08-31 rebrand for LSAF                                                          *;
%*                                                                                               *;

%macro sasdrugdev_syncfiletoworkspace(
  sdd_path=,
  sdd_version=
  ) /des='Get latest or specific version of a SAS Drug Development repository file to the workspace.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_syncfiletoworkspace(
    lsaf_path=&sdd_path,
    lsaf_version=&sdd_version
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_syncfiletoworkspace;
