%* sasdrugdev_unassignrole                                                                       *;
%*                                                                                               *;
%* Unassigns a role from the specified organization, project, or analysis.                       *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_UNASSIGNROLE(SDD_PATH=sdd-path, SDD_ROLE=sdd-role-name,                           *;
%* SDD_ROLE_CONTEXT=sdd-role-context);                                                           *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the context object (organization, project, or        *;
%*            analysis) from which to unassign the role.                                         *;
%* @param sdd_role - required - the name of the role being unassigned.                           *;
%* @param sdd_role_context - required - specifies the context in which the role is defined as a  *;
%*                   path (e.g., /SAS).                                                          *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_unassignrole, effective with SAS LSAF Macro 1.5                  *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_unassignrole(
  sdd_path=,
  sdd_role=,
  sdd_role_context=
  ) /des='Unassign a role from a context.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_unassignrole(
    lsaf_path=&sdd_path,
    lsaf_role=&sdd_role,
    lsaf_role_context=&sdd_role_context
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_unassignrole ;
