%* sasdrugdev_updateanalysisstate                                                                *;
%*                                                                                               *;
%* Update the state of an analysis in the SAS Drug Development repository                        *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_UPDATEANALYSISSTATE(SDD_PATH=sdd-path, SDD_STATE=sdd-state,                       *;
%* < SDD_COMMENT=sdd-comment >);                                                                 *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the analysis to be updated.                          *;
%* @param sdd_state - required - the state to set on the analysis.                               *;
%*            Values:  DEV | PROD | CLOSED                                                       *;
%* @param sdd_comment - optional - the reason for the state change.                              *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_updateanalysisstate, effective with SAS LSAF Macro 1.5           *;
%*                                                                                               *;
%* @history 2014-05-01 initial coding                                                            *;
%* @history 2016-08-31 rebrand for LSAF                                                          *;
%*                                                                                               *;

%macro sasdrugdev_updateanalysisstate(
  sdd_path=,
  sdd_state=,
  sdd_comment=
  ) /des='Update the state of an analysis.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_updateanalysisstate(
    lsaf_path=&sdd_path,
    lsaf_state=&sdd_state,
    lsaf_comment=&sdd_comment
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_updateanalysisstate;
