%* sasdrugdev_updatefile                                                                         *;
%*                                                                                               *;
%* Updates the contents of an existing file in the SAS Drug Development repository.              *;
%*                                                                                               *;
%* If the file is versioned a new version will be created.  If the file is not versioned, the    *;
%* existing contents will be overwritten.                                                        *;
%*                                                                                               *;
%* NOTE: This macro is only supported from a PC SAS session. Using this macro within an active   *;
%* SAS Drug Development application session will result in a failure.                            *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_UPDATEFILE(LOCAL_PATH=local-path, SDD_PATH=sdd-path <, SDD_COMMENT=sdd-comment>,  *;
%* SDD_VERSION=sdd-version-type);                                                                *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param local_path - required - the absolute path of the file on the local computer.           *;
%* @param sdd_path - required - the path of the content object in the SAS Drug Development       *;
%*            repository to update. The object must already exist and may not be a container.    *;
%* @param sdd_comment - conditional - the comment for a versioned file in the repository. This   *;
%*            value is ignored for non-versioned objects.                                        *;
%* @param sdd_version - conditional - the type of version to be created if the file to be        *;
%*            updated is versioned. Valid values are MAJOR or MINOR. The default is MINOR. This  *;
%*            value is ignored for non-versioned objects.                                        *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.1                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_updatefile, effective with SAS LSAF Macro 1.5                    *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_updatefile(
  local_path=,
  sdd_path=,
  sdd_comment=,
  sdd_version=
  ) /des='Update the contents of an existing SAS Drug Development object.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_updatefile(
    local_path=&local_path,
    lsaf_path=&sdd_path,
    lsaf_comment=&sdd_comment,
    lsaf_version=&sdd_version
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_updatefile ;
