%* sasdrugdev_updateowner                                                                        *;
%*                                                                                               *;
%* Updates the current owner of an object within the organization in the SAS Drug Development    *;
%* repository.                                                                                   *;
%*                                                                                               *;
%* Syntax for files:                                                                             *;
%* %SASDRUGDEV_UPDATEOWNER(SDD_PATH=sdd-path, SDD_USERID=sdd-userid);                            *;
%*                                                                                               *;
%* Syntax for containers:                                                                        *;
%* %SASDRUGDEV_UPDATEOWNER(SDD_PATH=sdd-path, SDD_USERID=sdd-userid, SDD_ACLTYPE=sdd-acl-type);  *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the content object in the SAS Drug Development       *;
%*            repository.                                                                        *;
%* @param sdd_userid - required - the user ID for the account that will be the new owner. To set *;
%*            the owner for the DEFAULT permissions to be the creator of the objects, specify    *;
%*            the value <creator> as the value for sdd-userid.                                   *;
%* @param sdd_aclType - conditional - the type of permission owner being set. The valid values   *;
%*            are DEFAULT and CURRENT (case-insensitive). Files only have CURRENT permissions,   *;
%*            therefore, the value is not required when the sdd_path is a file. For container    *;
%*            objects the value must be specified. The operation will fail if DEFAULT is         *;
%*            requested for a file path.                                                         *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.2                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_updateowner, effective with SAS LSAF Macro 1.5                   *;
%*                                                                                               *;
%* @history 2013-08-30  updates for standardization and coding conventions                       *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_updateowner(
  sdd_path=,
  sdd_aclType=,
  sdd_userid=
  ) /des='Change the owner of an object.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_updateowner(
    lsaf_path=&sdd_path,
    lsaf_aclType=&sdd_aclType,
    lsaf_userid=&sdd_userid
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_updateowner;
