%* sasdrugdev_updateprojectstate                                                                 *;
%*                                                                                               *;
%* Update the state of a project in the SAS Drug Development repository                          *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_UPDATEPROJECTSTATE(SDD_PATH=sdd-path, SDD_STATE=sdd-state,                        *;
%* < SDD_COMMENT=sdd-comment, SDD_INCLUDE_ANALYSES=sdd-include-analyses >);                      *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the project to be updated.                           *;
%* @param sdd_state - required - the state to set on the project.                                *;
%*            Values:  DEV | PROD | CLOSED                                                       *;
%* @param sdd_comment - optional - the reason for the state change.                              *;
%* @param sdd_include_analyses - optional - whether project child analyses, if any exist, should *;
%*            have their state updated as well.                                                  *;
%*            Values: 0 | 1                                                                      *;
%*            If no value is supplied, the child analysis states will be updated to the same     *;
%*            state value as supplied for the project.                                           *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_updateprojectstate, effective with SAS LSAF Macro 1.5            *;
%*                                                                                               *;
%* @history 2014-05-01 initial coding                                                            *;
%* @history 2016-08-31 rebrand for LSAF                                                          *;
%*                                                                                               *;

%macro sasdrugdev_updateprojectstate(
  sdd_path=,
  sdd_state=,
  sdd_comment=,
  sdd_include_analyses=1
  ) /des='Update the state of a project.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_updateprojectstate(
    lsaf_path=&sdd_path,
    lsaf_state=&sdd_state,
    lsaf_comment=&sdd_comment,
    lsaf_include_analyses=&sdd_include_analyses
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_updateprojectstate;
