%* sasdrugdev_updateproperties                                                                   *;
%*                                                                                               *;
%* Updates the editable properties of SAS Drug Development repository object using a SAS data    *;
%* set as input.                                                                                 *;
%*                                                                                               *;
%* The output data set from the sasdrugdev_getproperties macro contains the necessary variables  *;
%* and data needed as the input data set for the sasdrugdev_updateproperties macro. The column   *;
%* isReadonly flags if the field can be updated, 0 allows updates, 1 does not. Modify the        *;
%* data set with any changes prior to calling sasdrugdev_updateproperties.                       *;
%* - Data in the input data set that do not correspond to a property of the object being updated *;
%*   will be ignored.                                                                            *;
%* - Values specified for properties that are not editable will be ignored.                      *;
%* - An input data value that is the same as the current property value will be ignored and will *;
%*   not result in a property update.  No audit record will be created for the property.         *;
%*                                                                                               *;
%* Organization, project, and analysis leads cannot be updated via the                           *;
%* sasdrugdev_updateproperties macro.  Use the sasdrugdev_updateorglead,                         *;
%* sasdrugdev_updateprojectlead, sasdrugdev_updateanalysislead macros, to update organization,   *;
%* project, and analysis leads, respectively.                                                    *;
%*                                                                                               *;
%* Project and analysis state and state comment cannot be updated via the                        *;
%* sasdrugdev_updateproperties macro.  Use the sasdrugdev_updateprojectstate and                 *;
%* sasdrugdev_updateanalysis state macros for this purpose.                                      *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_UPDATEPROPERTIES(SDD_PATH=sdd-path, SAS_DSNAME=SAS-data-set);                     *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_path - required - the path of the object in the SAS Drug Development repository.   *;
%* @param sas_dsname - required - the name of a SAS data set containing the property values      *;
%*            to be set on the repository object specified as libref.dataset.  The data set must *;
%*            contain, at minimum, the variables listed below.  Any additional variables will    *;
%*            be ignored.                                                                        *;
%*            - name: the name of the property to be updated.                                    *;
%*            - value: the value to set on the property.                                         *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_updateproperties, effective with SAS LSAF Macro 1.5              *;
%*                                                                                               *;
%* @history 2014-04-24  initial coding                                                           *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_updateproperties(
  sdd_path=,
  sas_dsname=
  ) /des='Updates properties of a SAS Drug Development repository object based on the input data set';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_updateproperties(
    lsaf_path=&sdd_path,
    sas_dsname=&sas_dsname
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_updateproperties;
