%* sasdrugdev_updateuserinfo                                                                     *;
%*                                                                                               *;
%* Update general user account information                                                       *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_UPDATEUSERINFO(SDD_USERID=sdd-userid, < SDD_DISPLAYNAME=sdd-displayname,          *;
%* SDD_EMAIL=sdd-email, SDD_ACCOUNTTYPE=sdd-accounttype, SDD_FIRSTNAME=sdd-firstname,            *;
%* SDD_LASTNAME=sdd-lastname, SDD_DEPARTMENT=sdd-department, SDD_PHONE=sdd-phone >);             *;
%*                                                                                               *;
%* You must have either the Manage User Account General Information or the Manage Users global   *;
%* privilege in order to update user information.                                                *;
%*                                                                                               *;
%* If an optional parameter is not passed in, no change to the existing user attribute value     *;
%* will be made.  If the parameter is pased in, the specified value will be set on the user      *;
%* attribute. Parameter values must conform to SDD validation rules.                             *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param sdd_userid - required - the user ID of the account being updated.                      *;
%* @param sdd_displayname - optional - the user display name to be set.                          *;
%* @param sdd_email - optional - the user email address.                                         *;
%* @param sdd_accounttype - optional - the user account type.                                    *;
%*            Values:  INTERACTIVE | NON_INTERACTIVE                                             *;
%* @param sdd_firstname - optional - the user first name.                                        *;
%* @param sdd_lastname - optional - the last name of the user.                                   *;
%* @param sdd_department - optional - the business unit of the user.                             *;
%* @param sdd_phone - optional - the phone number of the user.                                   *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_updateuserinfo, effective with SAS LSAF Macro 1.5                *;
%*                                                                                               *;
%* @history 2014-03-27 initial coding                                                            *;
%* @history 2016-08-30  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_updateuserinfo(
  sdd_userid=,
  sdd_displayname=_sdd_updateuser_donotupdate_,
  sdd_email=_sdd_updateuser_donotupdate_,
  sdd_accounttype=_sdd_updateuser_donotupdate_,
  sdd_firstname=_sdd_updateuser_donotupdate_,
  sdd_lastname=_sdd_updateuser_donotupdate_,
  sdd_department=_sdd_updateuser_donotupdate_,
  sdd_phone=_sdd_updateuser_donotupdate_
  ) /des='Update a user account in the system.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_=%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %local sddNoUpdateText lsafNoUpdateText;

  %let sddNoUpdateText=_sdd_updateuser_donotupdate_;
  %let lsafNoUpdateText=_lsaf_updateuser_donotupdate_;


  %if (&sdd_displayname eq &sddNoUpdateText) %then
     %let sdd_displayname = &lsafNoUpdateText;

  %if (&sdd_email eq &sddNoUpdateText) %then
     %let sdd_email = &lsafNoUpdateText;

  %if (&sdd_accounttype eq &sddNoUpdateText) %then
     %let sdd_accounttype = &lsafNoUpdateText;

  %if (&sdd_firstname eq &sddNoUpdateText) %then
     %let sdd_firstname = &lsafNoUpdateText;

  %if (&sdd_lastname eq &sddNoUpdateText) %then
     %let sdd_lastname = &lsafNoUpdateText;

  %if (&sdd_department eq &sddNoUpdateText) %then
     %let sdd_department = &lsafNoUpdateText;

  %if (&sdd_phone eq &sddNoUpdateText) %then
     %let sdd_phone = &lsafNoUpdateText;

  %lsaf_updateuserinfo(
     lsaf_userid=&sdd_userid,
     lsaf_displayname=&sdd_displayname,
     lsaf_email=&sdd_email,
     lsaf_accounttype=&sdd_accounttype,
     lsaf_firstname=&sdd_firstname,
     lsaf_lastname=&sdd_lastname,
     lsaf_department=&sdd_department,
     lsaf_phone=&sdd_phone
  );


  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );
  run;

%mend sasdrugdev_updateuserinfo;
