%* sasdrugdev_uploadandexpand                                                                    *;
%*                                                                                               *;
%* Uploads and expands the contents of a zip file into the specified folder location in the SAS  *;
%* Drug Development repository.                                                                  *;
%*                                                                                               *;
%* NOTE: This macro is only supported from a PC SAS session. Using this macro within an active   *;
%* SAS Drug Development application session will result in a failure.                            *;
%*                                                                                               *;
%* Failure and Message Handling:                                                                 *;
%* The action status for each file that is being uploaded and each folder that is being created  *;
%* will be printed in the log.                                                                   *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_UPLOADANDEXPAND(LOCAL_PATH=local-zipfile-path, SDD_PATH=sdd-path                  *;
%* <, SDD_VERSIONING=sdd-versioning, SDD_VERSION=sdd-version, SDD_COMMENT=sdd_comment>);         *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%*                                                                                               *;
%* @param local_path - required - the absolute path and name of the zip file on the local        *;
%*            computer.                                                                          *;
%* @param sdd_path - required - the path of the target folder.                                   *;
%* @param sdd_versioning - optional - indicates whether the new files being created should be    *;
%*            versioned. The default value is 0, which will create a non-versioned file.  A      *;
%*            value of 1 will create a versioned file. The versioning status of existing         *;
%*            files will not be changed.                                                         *;
%*            Values:  0 | 1                                                                     *;
%*            Default: 0                                                                         *;
%* @param sdd_version - optional - the type of version to be created if the new files are to be  *;
%*            versioned. Valid values are MAJOR or MINOR. The default is MINOR. This value is    *;
%*            ignored for non-versioned objects.                                                 *;
%* @param sdd_comment - conditional - the comment for the versioned file being created. This     *;
%*            option is ignored when creating non-versioned files.                               *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.4                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_uploadandexpand, effective with SAS LSAF Macro 1.5               *;
%*                                                                                               *;
%* @history 2013-03-18  initial code                                                             *;
%* @history 2016-08-31  rebrand for LSAF                                                         *;
%*                                                                                               *;

%macro sasdrugdev_uploadandexpand(
  local_path=,
  sdd_path=,
  sdd_versioning=,
  sdd_version=,
  sdd_comment=
  ) /des='Uploads and expands a zip file into the SAS Drug Development repository.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_uploadandexpand(
    local_path=&local_path,
    lsaf_path=&sdd_path,
    lsaf_versioning=&sdd_versioning,
    lsaf_version=&sdd_version,
    lsaf_comment=&sdd_comment
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_uploadandexpand;
