%* sasdrugdev_userexists                                                                         *;
%*                                                                                               *;
%* Determines whether a user exists within the system.                                           *;
%*                                                                                               *;
%* The macro variable _sddUserExists_ will be set to 1 if the user exists, 0 if it does not.     *;
%* In the event of an incorrect call to the macro which results in an error, the return value    *;
%* of _sddUserExists_ will be set to -1.                                                         *;
%*                                                                                               *;
%* Syntax:                                                                                       *;
%* %SASDRUGDEV_USEREXISTS(SDD_USERID=sdd-userid);                                                *;
%*                                                                                               *;
%* @macvar _sddRC_  the return code.                                                             *;
%* @macvar _sddMsg_ the return message.                                                          *;
%* @macvar _sddUserExists_ indicates if the user exists.                                         *;
%*                                                                                               *;
%* @param sdd_userid - required - the user ID of the user account to check.                      *;
%*                                                                                               *;
%* @macrotype SDD                                                                                *;
%* @since 1.3                                                                                    *;
%* @exposure external                                                                            *;
%* @deprecated Replaced by lsaf_userexists, effective with SAS LSAF Macro 1.5                    *;
%*                                                                                               *;
%* @history 2013-10-30 initial coding                                                            *;
%* @history 2016-08-31 rebrand for LSAF                                                          *;
%*                                                                                               *;

%macro sasdrugdev_userexists(
  sdd_userid=
  ) /des='Is the user defined in the system.';

  %****************************************;
  %* Initialize macro variables           *;
  %****************************************;
  %global _sddUserExists_
          _sddMsg_
          _sddRC_
  ;

  %let _sddRC_ =%str(-999);
  %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_userexists(lsaf_userid=&sdd_userid);

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=_sddUserExists_,
    lsaf_answer_val=&_lsafUserExists_
  );

%mend sasdrugdev_userexists ;
