%* sasdrugdev_validate_sasdataset.sas                                                  *;
%*                                                                                     *;
%* Validates the data set sent in by the user to the SAS macros.  Tests that           *;
%* - data set has a validate SAS name                                                  *;
%* - exists                                                                            *;
%* - is not empty (has observations)                                                   *;
%* - includes the required variables                                                   *;
%* - required variables are of  the correct variable type (character or numeric)       *;
%*                                                                                     *;
%* Syntax:                                                                             *;
%* %SASDRUGDEV_VALIDATE_SASDATASET(SAS_DSN=SAS-data-set                                *;
%*            <, CALLINGMACRO=calling-macro, REQUIRED_VARIABLES=required-var-list,     *;
%*            REQUIRED_NUMERIC_VARIABLES=required-numeric-list> );                     *;
%*                                                                                     *;
%* @macvar _sddRC_  the return code.                                                   *;
%* @macvar _sddMsg_ the return message.                                                *;
%*                                                                                     *;
%* @param sas_dsn - required - the name of the dataset that is being validated.        *;
%* @param callingMacro - optional - the macro calling this one.                        *;
%* @param required_variables - optional - a space-delimited list of data set variables *;
%*             that are required to be present in the data set.                        *;
%* @param required_numeric_variables - optional - a space-delimited list of the        *;
%*             required variables that should be of type numeric. If a required        *;
%*             variable is not included in this list, it will be validated as a        *;
%*             character.                                                              *;
%*                                                                                     *;
%* @macrotype SDD                                                                      *;
%* @since 1.2                                                                          *;
%* @exposure internal                                                                  *;
%* @deprecated Replaced by lsaf_validate_sasdataset, effective with SAS LSAF Macro 1.5 *;
%*                                                                                     *;
%* @history 2013-08-30  updates for standardization and coding conventions.            *;
%* @history 2014-03-28  decoupled from updateacls.                                     *;
%* @history 2016-08-31  rebrand for LSAF                                               *;
%*                                                                                     *;

%macro sasdrugdev_validate_sasdataset(
   sas_dsn=,
   callingMacro=,
   required_variables=,
   required_numeric_variables=%str()
   ) / des='Validates a SAS data set.';

   %****************************************;
   %* Initialize macro variables           *;
   %****************************************;
   %global _sddMsg_
           _sddRC_
   ;

   %let _sddRC_=%str(-999);
   %let _sddMsg_=%str(The SAS Macro did not execute properly.  Unknown err%str(or).);

  %****************************************;
  %* Call LSAF macro.                     *;
  %****************************************;
  %lsaf_validate_sasdataset(
    sas_dsn=&sas_dsn,
    callingMacro=&callingMacro,
    required_variables=&required_variables,
    required_numeric_variables=&required_numeric_variables
  );

  %***************************************;
  %* Call LSAF transition code           *;
  %***************************************;
  %let _sddMacro_=&SYSMACRONAME;
  %lsaf_transition(
    sdd_macro_name=%lowcase(&_sddMacro_),
    sdd_answer_var=,
    lsaf_answer_val=
  );

%mend sasdrugdev_validate_sasdataset;
